@@ -9,21 +9,17 @@
 # This code is inspired by PySol by Markus F.X.J. Oberhumer and others.
 # See: http://pysolfc.sourceforge.net/ .
 import random2
-import re
 import sys
-from fc_solve_find_index_s2ints import createCards, Card, ms_rearrange
+from fc_solve_find_index_s2ints import createCards, Card, CardRenderer, \
+        find_index__board_string_to_ints, ms_rearrange
 
 
 def empty_card():
-    ret = Card(0, 0, 0, True)
+    ret = Card(0, 0, 0)
     ret.empty = True
     return ret
 
 
-def column_to_string(col):
-    return ' '.join([x.to_s() for x in col])
-
-
 class RandomBase:
     DEALS_PYSOL = 0
     DEALS_PYSOLFC = 1
@@ -113,10 +109,6 @@ class Columns:
     def rev(self):
         self.cols.reverse()
 
-    def output(self):
-        for c in self.cols:
-            print(column_to_string(c))
-
 
 class Board:
     def __init__(self, num_columns, with_freecells=False,
@@ -124,6 +116,7 @@ class Board:
         self.with_freecells = with_freecells
         self.with_talon = with_talon
         self.with_foundations = with_foundations
+        self.raw_foundations_line = None
         self.columns = Columns(num_columns)
         if self.with_freecells:
             self.freecells = []
@@ -160,30 +153,31 @@ class Board:
             self.foundations[card.suit] = card
         return res
 
-    def print_foundations(self):
+    def print_foundations(self, renderer):
         cells = []
         for f in [2, 0, 3, 1]:
             if not self.foundations[f].empty:
-                cells.append(self.foundations[f].found_s())
+                cells.append(renderer.found_s(self.foundations[f]))
 
         if len(cells):
             self.add_line("Foundations:" + ("".join([" "+s for s in cells])))
 
-    def gen_lines(self):
+    def gen_lines(self, renderer):
         self._lines = []
         if self.with_talon:
-            self.add_line("Talon: " + column_to_string(self.talon))
+            self.add_line("Talon: " + renderer.l_concat(self.talon))
         if self.with_foundations:
-            self.print_foundations()
+            self.print_foundations(renderer)
+        if self.raw_foundations_line:
+            self.add_line(self.raw_foundations_line)
         if self.with_freecells:
-            self.add_line("Freecells: " + column_to_string(self.freecells))
+            self.add_line("Freecells: " + renderer.l_concat(self.freecells))
 
-        self._lines += [column_to_string(c) for c in self.columns.cols]
+        self._lines += [renderer.l_concat(c) for c in self.columns.cols]
 
-    def output(self):
-        self.gen_lines()
-        for l in self._lines:
-            print(l)
+    def calc_string(self, renderer):
+        self.gen_lines(renderer)
+        return "".join(l + "\n" for l in self._lines)
 
 
 def shuffle(cards, game_num, which_deals):
@@ -221,7 +215,7 @@ class Game:
                 "all_in_a_row": None,
         }
 
-    def __init__(self, game_id, game_num, which_deals, print_ts):
+    def __init__(self, game_id, game_num, which_deals, max_rank=13):
         mymap = {}
         for k, v in self.REVERSE_MAP.items():
             for name in [k] + (v if v else []):
@@ -229,8 +223,11 @@ class Game:
         self.games_map = mymap
         self.game_id = game_id
         self.game_num = game_num
-        self.print_ts = print_ts
         self.which_deals = which_deals
+        self.max_rank = max_rank
+        self.game_class = self.games_map[self.game_id]
+        if not self.game_class:
+            raise ValueError("Unknown game type " + self.game_id + "\n")
 
     def is_two_decks(self):
         return self.game_id in ("der_katz", "der_katzenschwantz",
@@ -239,21 +236,27 @@ class Game:
     def get_num_decks(self):
         return 2 if self.is_two_decks() else 1
 
-    def print_layout(self):
-        game_class = self.games_map[self.game_id]
-        if not game_class:
-            raise ValueError("Unknown game type " + self.game_id + "\n")
-
+    def calc_deal_string(self, game_num, renderer):
+        self.game_num = game_num
         self.deal()
-        getattr(self, game_class)()
-        self.board.output()
+        getattr(self, self.game_class)()
+        return self.board.calc_string(renderer)
+
+    def calc_layout_string(self, renderer):
+        self.deal()
+        getattr(self, self.game_class)()
+        return self.board.calc_string(renderer)
+
+    def print_layout(self, renderer):
+        print(self.calc_layout_string(renderer), sep='', end='')
 
     def new_cards(self, cards):
         self.cards = cards
         self.card_idx = 0
 
     def deal(self):
-        cards = shuffle(createCards(self.get_num_decks(), self.print_ts),
+        cards = shuffle(createCards(self.get_num_decks(),
+                                    self.max_rank),
                         self.game_num, self.which_deals)
         cards.reverse()
         self.new_cards(cards)
@@ -317,7 +320,7 @@ class Game:
             lambda c: (c.id == 13, c.suit),
             1)
         game.cyclical_deal(52, 13)
-        print('Foundations: -')
+        game.board.raw_foundations_line = 'Foundations: -'
 
     def bakers_dozen(game):
         n = 13
@@ -362,7 +365,7 @@ class Game:
             1)
         next(game)
         game.cyclical_deal(52-1, 17)
-        print('Foundations: AS')
+        game.board.raw_foundations_line = 'Foundations: AS'
 
     def der_katz(game):
         is_ds = game.game_id == 'die_schlange'
@@ -384,7 +387,8 @@ class Game:
     def freecell(game):
         is_fc = (game.game_id in ("forecell", "eight_off"))
         game.board = Board(8, with_freecells=is_fc)
-        game.cyclical_deal((48 if is_fc else 52), 8)
+        game.cyclical_deal(4 *
+                           (game.max_rank-1 if is_fc else game.max_rank), 8)
 
         if is_fc:
             for c in game:
@@ -437,11 +441,15 @@ class Game:
 def make_pysol_board__main(args):
     print_ts = False
     which_deals = RandomBase.DEALS_PYSOL
+    max_rank = 13
     while args[1][0] == '-':
         a = args[1]
         if a == "-t":
             print_ts = True
             args.pop(1)
+        elif (a == "--max-rank"):
+            args.pop(1)
+            max_rank = int(args.pop(1))
         elif (a == "--pysolfc") or (a == "-F"):
             which_deals = RandomBase.DEALS_PYSOLFC
             args.pop(1)
@@ -453,54 +461,15 @@ def make_pysol_board__main(args):
 
     game_num = int(args[1])
     which_game = args[2] if len(args) >= 3 else "freecell"
-    game = Game(which_game, game_num, which_deals, print_ts)
-    game.print_layout()
-
-
-def find_index__board_string_to_ints(content):
-    rank_s = 'A23456789TJQK'
-    rank_re = r'[' + rank_s + r']'
-    suit_s = 'CSHD'
-    suit_re = r'[' + suit_s + r']'
-
-    card_re = rank_re + suit_re
-    card_re_paren = r'(' + card_re + r')'
-
-    def make_line(n):
-        return r':?[ \t]*' + card_re_paren + \
-            (r'[ \t]+' + card_re_paren) * (n-1) + r'[ \t]*\n'
-
-    complete_re = r'^' + make_line(7) * 4 + make_line(6) * 4 + '\s*$'
-
-    m = re.match(complete_re, content)
-    if not m:
-        raise ValueError("Could not match.")
-
-    cards = [x.to_s() for x in ms_rearrange(createCards(1, True))]
-
-    # Reverse shuffle:
-    ints = []
-    n = 4 * 13 - 1
-    for i in range(n):
-        col = i // 8
-        row = i % 8
-        s = m.group(1 + col + (4*7+(row-4)*6 if row >= 4 else row*7))
-        idx = [j for j in range(n+1) if cards[j] == s]
-        if len(idx) != 1:
-            raise ValueError("Foo")
-        j = idx[0]
-        ints.append(j)
-        cards[j] = cards[n]
-        n -= 1
-
-    return ints
+    Game(which_game, game_num, which_deals, max_rank).print_layout(
+        CardRenderer(print_ts))
 
 
 def find_index_main(args, find_ret):
     output_to_stdout = True
     output_fn = None
     is_ms = False
-    while args[1][0] == '-':
+    while len(args) >= 2 and args[1][0] == '-':
         if args[1] == "-o":
             args.pop(1)
             if not len(args):
