@@ -16,10 +16,11 @@ extern "C" {
 
 #include "state.h"
 
-typedef enum {
+typedef enum
+{
     FCS_DBM_VARIANT_2FC_FREECELL,
     FCS_DBM_VARIANT_BAKERS_DOZEN,
-} fcs_dbm_variant_type_t;
+} fcs_dbm_variant_type;
 
 #ifndef FCS_DBM_FREECELLS_NUM
 #define FCS_DBM_FREECELLS_NUM 2
