@@ -7,12 +7,11 @@
  *
  * Copyright (c) 2012 Shlomi Fish
  */
-/*
- * dbm_kaztree_compare.h - contains the comparison routine. The record_t
- * definition can be found in delta_states.h.
- * Intended for dbm_kaztree.c. Should only be included by it and programs
- * that test it.
- */
+// dbm_kaztree_compare.h - contains the comparison routine. The record_t
+// definition can be found in delta_states.h.
+//
+// Intended for dbm_kaztree.c. Should only be included by it and programs
+// that test it.
 #pragma once
 
 #ifdef __cplusplus
@@ -25,9 +24,9 @@ extern "C" {
 static int compare_records(
     const void *const void_a, const void *const void_b, void *const context)
 {
-#define GET_PARAM(p) (&(((const fcs_dbm_record_t *)(p))->key))
-    const fcs_encoded_state_buffer_t *const a = GET_PARAM(void_a),
-                                            *const b = GET_PARAM(void_b);
+#define GET_PARAM(p) (&(((const fcs_dbm_record *)(p))->key))
+    const fcs_encoded_state_buffer *const a = GET_PARAM(void_a),
+                                          *const b = GET_PARAM(void_b);
 #undef GET_PARAM
 
     if (a->s[0] < b->s[0])
@@ -47,7 +46,7 @@ static int compare_records(
 static int compare_records(const void *const void_a, const void *const void_b,
     void *const context GCC_UNUSED)
 {
-#define GET_PARAM(p) (((const fcs_dbm_record_t *)(p))->key)
+#define GET_PARAM(p) (((const fcs_dbm_record *)(p))->key)
     return memcmp(
         &(GET_PARAM(void_a)), &(GET_PARAM(void_b)), sizeof(GET_PARAM(void_a)));
 #undef GET_PARAM
