@@ -12,51 +12,42 @@
 #include "read_state.h"
 typedef struct
 {
-    fcs_dbm_solver_thread_t thread;
-    thread_arg_t arg;
+    dbm_solver_thread thread;
+    thread_arg arg;
     pthread_t id;
-} main_thread_item_t;
+} main_thread_item;
 
-static inline main_thread_item_t *dbm__calc_threads(
-    fcs_dbm_solver_instance_t *const instance,
-    fcs_state_keyval_pair_t *const init_state, const size_t num_threads,
-    void (*init_thread_cb)(fcs_dbm_solver_thread_t *))
+static inline main_thread_item *dbm__calc_threads(
+    dbm_solver_instance *const instance,
+    fcs_state_keyval_pair *const init_state, const size_t num_threads,
+    void (*init_thread_cb)(dbm_solver_thread *))
 {
 #ifdef T
     FILE *const out_fh = instance->common.out_fh;
 #endif
-#ifndef FCS_FREECELL_ONLY
     const_AUTO(local_variant, instance->common.variant);
-#endif
-    main_thread_item_t *const threads = SMALLOC(threads, num_threads);
+    main_thread_item *const threads = SMALLOC(threads, num_threads);
     TRACE("%s\n", "instance_run_all_threads start");
 #ifdef DEBUG_FOO
-    fc_solve_delta_stater_init(
-        &global_delta_stater, &(init_state->s), STACKS_NUM, FREECELLS_NUM
-#ifndef FCS_FREECELL_ONLY
-        ,
-        FCS_SEQ_BUILT_BY_ALTERNATE_COLOR
-#endif
-    );
+    fc_solve_delta_stater_init(&global_delta_stater, &(init_state->s),
+        STACKS_NUM,
+        FREECELLS_NUM PASS_ON_NOT_FC_ONLY(FCS_SEQ_BUILT_BY_ALTERNATE_COLOR));
 #endif
     for (size_t i = 0; i < num_threads; i++)
     {
         threads[i].thread.instance = instance;
         fc_solve_delta_stater_init(&(threads[i].thread.delta_stater),
-            &(init_state->s), STACKS_NUM, FREECELLS_NUM
-#ifndef FCS_FREECELL_ONLY
-            ,
-            FCS_SEQ_BUILT_BY_ALTERNATE_COLOR
-#endif
-        );
+            local_variant, &(init_state->s), STACKS_NUM,
+            FREECELLS_NUM PASS_ON_NOT_FC_ONLY(
+                FCS_SEQ_BUILT_BY_ALTERNATE_COLOR));
         init_thread_cb(threads[i].arg.thread = &(threads[i].thread));
     }
     return threads;
 }
 
-static inline void dbm__free_threads(fcs_dbm_solver_instance_t *const instance,
-    const size_t num_threads, main_thread_item_t *const threads,
-    void (*free_thread_cb)(fcs_dbm_solver_thread_t *))
+static inline void dbm__free_threads(dbm_solver_instance *const instance,
+    const size_t num_threads, main_thread_item *const threads,
+    void (*free_thread_cb)(dbm_solver_thread *))
 {
 #ifdef T
     FILE *const out_fh = instance->common.out_fh;
@@ -74,17 +65,17 @@ static inline void dbm__free_threads(fcs_dbm_solver_instance_t *const instance,
 }
 
 static unsigned char get_move_from_parent_to_child(
-    fcs_dbm_solver_instance_t *const instance, fc_solve_delta_stater_t *delta,
-    fcs_encoded_state_buffer_t parent, fcs_encoded_state_buffer_t child)
+    dbm_solver_instance *const instance, fcs_delta_stater *delta,
+    fcs_encoded_state_buffer parent, fcs_encoded_state_buffer child)
 {
-    fcs_state_keyval_pair_t parent_state;
-    fcs_derived_state_t *derived_list = NULL, *derived_list_recycle_bin = NULL;
+    fcs_state_keyval_pair parent_state;
+    fcs_derived_state *derived_list = NULL, *derived_list_recycle_bin = NULL;
     DECLARE_IND_BUF_T(indirect_stacks_buffer)
     const_AUTO(local_variant, instance->common.variant);
 
-    fcs_meta_compact_allocator_t meta_alloc;
+    meta_allocator meta_alloc;
     fc_solve_meta_compact_allocator_init(&meta_alloc);
-    fcs_compact_allocator_t derived_list_allocator;
+    compact_allocator derived_list_allocator;
     fc_solve_compact_allocator_init(&(derived_list_allocator), &meta_alloc);
     fc_solve_delta_stater_decode_into_state(
         delta, parent.s, &parent_state, indirect_stacks_buffer);
@@ -96,7 +87,7 @@ static unsigned char get_move_from_parent_to_child(
     for (var_AUTO(derived_iter, derived_list); derived_iter;
          derived_iter = derived_iter->next)
     {
-        fcs_encoded_state_buffer_t got_child;
+        fcs_encoded_state_buffer got_child;
         fcs_init_and_encode_state(
             delta, local_variant, &(derived_iter->state), &got_child);
         if (compare_enc_states(&got_child, &child) == 0)
@@ -110,20 +101,20 @@ static unsigned char get_move_from_parent_to_child(
     fc_solve_err("%s\n", "Failed to find move. Terminating.");
 }
 
-static void trace_solution(fcs_dbm_solver_instance_t *const instance,
-    FILE *const out_fh, fc_solve_delta_stater_t *const delta)
+static void trace_solution(dbm_solver_instance *const instance,
+    FILE *const out_fh, fcs_delta_stater *const delta)
 {
     fprintf(out_fh, "%s\n", "Success!");
     fflush(out_fh);
 /* Now trace the solution */
 #ifdef FCS_DBM_WITHOUT_CACHES
-    fcs_encoded_state_buffer_t *trace;
+    fcs_encoded_state_buffer *trace;
     int trace_num;
-    fcs_state_keyval_pair_t state;
+    fcs_state_keyval_pair state;
     unsigned char move = '\0';
     char move_buffer[500];
     DECLARE_IND_BUF_T(indirect_stacks_buffer)
-    fcs_state_locs_struct_t locs;
+    fcs_state_locs_struct locs;
     fc_solve_init_locs(&locs);
     const_AUTO(local_variant, instance->common.variant);
     calc_trace(instance->common.queue_solution_ptr, &trace, &trace_num);
@@ -139,7 +130,7 @@ static void trace_solution(fcs_dbm_solver_instance_t *const instance,
             move_to_string(move, move_buffer);
         }
 
-        fcs_render_state_str_t state_str;
+        fcs_render_state_str state_str;
         FCS__RENDER_STATE(state_str, &(state.s), &locs);
         fprintf(out_fh, "--------\n%s\n==\n%s\n", state_str,
             (i > 0) ? move_buffer : "END");
@@ -150,8 +141,9 @@ static void trace_solution(fcs_dbm_solver_instance_t *const instance,
 }
 
 static inline void read_state_from_file(
-    const fcs_dbm_variant_type_t local_variant, const char *const filename,
-    fcs_state_keyval_pair_t *const init_state IND_BUF_T_PARAM(
+    const fcs_dbm_variant_type local_variant GCC_UNUSED,
+    const char *const filename,
+    fcs_state_keyval_pair *const init_state IND_BUF_T_PARAM(
         init_indirect_stacks_buffer))
 {
     FILE *const fh = fopen(filename, "r");
@@ -159,11 +151,11 @@ static inline void read_state_from_file(
     {
         fc_solve_err("Could not open file '%s' for input.\n", filename);
     }
-    const fcs_user_state_str_t user_state = read_state(fh);
+    const fcs_user_state_str user_state = read_state(fh);
     fc_solve_initial_user_state_to_c(user_state.s, init_state, FREECELLS_NUM,
         STACKS_NUM, DECKS_NUM, init_indirect_stacks_buffer);
 #ifndef FCS_DISABLE_STATE_VALIDITY_CHECK
-    fcs_card_t problem_card;
+    fcs_card problem_card;
     if (FCS_STATE_VALIDITY__OK !=
         fc_solve_check_state_validity(init_state PASS_FREECELLS(FREECELLS_NUM)
                                           PASS_STACKS(STACKS_NUM)
