@@ -17,18 +17,50 @@
 extern "C" {
 #endif
 
+#include "bit_rw.h"
 #include "dbm_common.h"
 
 #ifdef FCS_DEBONDT_DELTA_STATES
+#include "var_base_writer.h"
+#include "var_base_reader.h"
 #define FCS_ENCODED_STATE_COUNT_CHARS 16
+#define CARD_ARRAY_LEN ((RANK_KING + 1) * FCS_NUM_SUITS)
+
+typedef struct
+{
+    FCS_ON_NOT_FC_ONLY(int sequences_are_built_by);
+    int num_freecells;
+    size_t num_columns;
+    fcs_state *init_state, *derived_state;
+    int bits_per_orig_cards_in_column;
+    int card_states[CARD_ARRAY_LEN];
+    int8_t bakers_dozen_topmost_cards_lookup[((1 << 6) / 8) + 1];
+    fcs_var_base_reader r;
+    fcs_var_base_writer w;
+} fcs_delta_stater;
+
 #else
 #define FCS_ENCODED_STATE_COUNT_CHARS 24
+typedef struct
+{
+    FCS_ON_NOT_FC_ONLY(int sequences_are_built_by);
+    size_t num_freecells;
+    size_t num_columns;
+    fcs_state *init_state, *derived_state;
+    int bits_per_orig_cards_in_column;
+} fcs_delta_stater;
 #endif
 
+static inline void fc_solve_delta_stater_set_derived(
+    fcs_delta_stater *const self, fcs_state *const state)
+{
+    self->derived_state = state;
+}
+
 typedef struct
 {
     unsigned char s[FCS_ENCODED_STATE_COUNT_CHARS];
-} fcs_encoded_state_buffer_t;
+} fcs_encoded_state_buffer;
 
 #if SIZEOF_VOID_P == 4
 #define FCS_EXPLICIT_REFCOUNT 1
@@ -38,32 +70,32 @@ typedef struct
 
 typedef struct
 {
-    fcs_encoded_state_buffer_t key;
+    fcs_encoded_state_buffer key;
     uintptr_t parent_and_refcount;
 #ifdef FCS_EXPLICIT_REFCOUNT
     unsigned char refcount;
 #endif
-} fcs_dbm_record_t;
+} fcs_dbm_record;
 
 #define FCS_DBM_RECORD_SHIFT ((sizeof(rec->parent_and_refcount) - 1) * 8)
 
 #ifdef FCS_EXPLICIT_REFCOUNT
-static inline fcs_dbm_record_t *fcs_dbm_record_get_parent_ptr(
-    fcs_dbm_record_t *const rec)
+static inline fcs_dbm_record *fcs_dbm_record_get_parent_ptr(
+    fcs_dbm_record *const rec)
 {
-    return (fcs_dbm_record_t *)(rec->parent_and_refcount);
+    return (fcs_dbm_record *)(rec->parent_and_refcount);
 }
 #else
-static inline fcs_dbm_record_t *fcs_dbm_record_get_parent_ptr(
-    fcs_dbm_record_t *const rec)
+static inline fcs_dbm_record *fcs_dbm_record_get_parent_ptr(
+    fcs_dbm_record *const rec)
 {
-    return (fcs_dbm_record_t *)(rec->parent_and_refcount &
-                                (~(((uintptr_t)0xFF) << FCS_DBM_RECORD_SHIFT)));
+    return (fcs_dbm_record *)(rec->parent_and_refcount &
+                              (~(((uintptr_t)0xFF) << FCS_DBM_RECORD_SHIFT)));
 }
 #endif
 
 static inline void fcs_dbm_record_set_parent_ptr(
-    fcs_dbm_record_t *const rec, fcs_dbm_record_t *const parent_ptr)
+    fcs_dbm_record *const rec, fcs_dbm_record *const parent_ptr)
 {
     rec->parent_and_refcount = ((uintptr_t)parent_ptr);
 #ifdef FCS_EXPLICIT_REFCOUNT
@@ -73,13 +105,13 @@ static inline void fcs_dbm_record_set_parent_ptr(
 
 #ifdef FCS_EXPLICIT_REFCOUNT
 static inline unsigned char fcs_dbm_record_get_refcount(
-    const fcs_dbm_record_t *const rec)
+    const fcs_dbm_record *const rec)
 {
     return rec->refcount;
 }
 #else
 static inline unsigned char fcs_dbm_record_get_refcount(
-    const fcs_dbm_record_t *const rec)
+    const fcs_dbm_record *const rec)
 {
     return (unsigned char)(rec->parent_and_refcount >> FCS_DBM_RECORD_SHIFT);
 }
@@ -87,13 +119,13 @@ static inline unsigned char fcs_dbm_record_get_refcount(
 
 #ifdef FCS_EXPLICIT_REFCOUNT
 static inline void fcs_dbm_record_set_refcount(
-    fcs_dbm_record_t *const rec, const unsigned char new_val)
+    fcs_dbm_record *const rec, const unsigned char new_val)
 {
     rec->refcount = new_val;
 }
 #else
 static inline void fcs_dbm_record_set_refcount(
-    fcs_dbm_record_t *const rec, const unsigned char new_val)
+    fcs_dbm_record *const rec, const unsigned char new_val)
 {
     rec->parent_and_refcount &=
         (~(((const uintptr_t)0xFF) << FCS_DBM_RECORD_SHIFT));
@@ -102,15 +134,14 @@ static inline void fcs_dbm_record_set_refcount(
 }
 #endif
 
-static inline void fcs_dbm_record_increment_refcount(
-    fcs_dbm_record_t *const rec)
+static inline void fcs_dbm_record_increment_refcount(fcs_dbm_record *const rec)
 {
     fcs_dbm_record_set_refcount(rec, fcs_dbm_record_get_refcount(rec) + 1);
 }
 
 /* Returns the new value so we can tell if it is zero. */
 static inline unsigned char fcs_dbm_record_decrement_refcount(
-    fcs_dbm_record_t *const rec)
+    fcs_dbm_record *const rec)
 {
     const unsigned char new_val = fcs_dbm_record_get_refcount(rec) - 1;
 
@@ -123,31 +154,17 @@ static inline unsigned char fcs_dbm_record_decrement_refcount(
 
 typedef struct
 {
-    fcs_encoded_state_buffer_t key;
-    fcs_encoded_state_buffer_t parent;
-} fcs_dbm_record_t;
+    fcs_encoded_state_buffer key;
+    fcs_encoded_state_buffer parent;
+} fcs_dbm_record;
 
 #endif
 
-typedef struct
-{
-#ifndef FCS_FREECELL_ONLY
-    int sequences_are_built_by;
-#endif
-    size_t num_freecells;
-    size_t num_columns;
-    fcs_state_t *init_state, *derived_state;
-    int bits_per_orig_cards_in_column;
-} fc_solve_delta_stater_t;
-
-static inline void fcs_init_encoded_state(fcs_encoded_state_buffer_t *enc_state)
+static inline void fcs_init_encoded_state(fcs_encoded_state_buffer *enc_state)
 {
     memset(enc_state, '\0', sizeof(*enc_state));
 }
 
-extern char *fc_solve_user_INTERNAL_delta_states_enc_and_dec(
-    fcs_dbm_variant_type_t, const char *, const char *);
-
 #ifdef __cplusplus
 }
 #endif
