@@ -14,36 +14,36 @@
  * delta_states.c for a very compact storage.
  *
  * In addition, this solver implements the scheme in:
- * http://tech.groups.yahoo.com/group/fc-solve-discuss/message/1135
+ * https://groups.yahoo.com/neo/groups/fc-solve-discuss/conversations/topics/1135
  */
 
 #include "dbm_solver_head.h"
 
 typedef struct
 {
-    fcs_dbm__cache_store__common_t cache_store;
-    fcs_meta_compact_allocator_t queue_meta_alloc;
-    fcs_offloading_queue_t queue;
-} fcs_dbm_collection_by_depth_t;
+    fcs_dbm__cache_store__common cache_store;
+    meta_allocator queue_meta_alloc;
+    fcs_offloading_queue queue;
+} fcs_dbm_collection_by_depth;
 
 #define MAX_FCC_DEPTH (RANK_KING * 4 * DECKS_NUM * 2)
-typedef size_t batch_size_t;
+typedef size_t fcs_batch_size;
 typedef struct
 {
-    fcs_dbm_collection_by_depth_t colls_by_depth[MAX_FCC_DEPTH];
-    fcs_condvar_t monitor;
+    fcs_dbm_collection_by_depth colls_by_depth[MAX_FCC_DEPTH];
+    fcs_condvar monitor;
     const char *offload_dir_path;
     int curr_depth;
-    fcs_dbm_instance_common_elems_t common;
-    batch_size_t max_batch_size;
-} fcs_dbm_solver_instance_t;
+    dbm_instance_common_elems common;
+    fcs_batch_size max_batch_size;
+} dbm_solver_instance;
 
 #define CHECK_KEY_CALC_DEPTH()                                                 \
     (instance->curr_depth + list->num_non_reversible_moves_including_prune)
 
 #include "dbm_procs.h"
-static inline void instance_init(fcs_dbm_solver_instance_t *const instance,
-    const fcs_dbm_common_input_t *const inp, const batch_size_t max_batch_size,
+static inline void instance_init(dbm_solver_instance *const instance,
+    const fcs_dbm_common_input *const inp, const fcs_batch_size max_batch_size,
     FILE *const out_fh)
 {
     instance->max_batch_size = max_batch_size;
@@ -70,7 +70,7 @@ static inline void instance_init(fcs_dbm_solver_instance_t *const instance,
     fcs_condvar_init(&(instance->monitor));
 }
 
-static inline void instance_destroy(fcs_dbm_solver_instance_t *const instance)
+static inline void instance_destroy(dbm_solver_instance *const instance)
 {
     for (int depth = 0; depth < MAX_FCC_DEPTH; depth++)
     {
@@ -87,29 +87,29 @@ static inline void instance_destroy(fcs_dbm_solver_instance_t *const instance)
 
 struct fcs_dbm_solver_thread_struct
 {
-    fcs_dbm_solver_instance_t *instance;
-    fc_solve_delta_stater_t delta_stater;
-    fcs_meta_compact_allocator_t thread_meta_alloc;
+    dbm_solver_instance *instance;
+    fcs_delta_stater delta_stater;
+    meta_allocator thread_meta_alloc;
 };
 
 static void *instance_run_solver_thread(void *const void_arg)
 {
-    fcs_derived_state_t *derived_list_recycle_bin = NULL;
-    fcs_state_keyval_pair_t state;
+    fcs_derived_state *derived_list_recycle_bin = NULL;
+    fcs_state_keyval_pair state;
 #ifdef DEBUG_OUT
-    fcs_state_locs_struct_t locs;
+    fcs_state_locs_struct locs;
     fc_solve_init_locs(&locs);
 #endif
     DECLARE_IND_BUF_T(indirect_stacks_buffer)
 
-    const_AUTO(thread, ((thread_arg_t *)void_arg)->thread);
+    const_AUTO(thread, ((thread_arg *)void_arg)->thread);
     const_SLOT(instance, thread);
     const_AUTO(delta_stater, &(thread->delta_stater));
     const_AUTO(local_variant, instance->common.variant);
     const_SLOT(max_batch_size, instance);
 
-    batch_size_t prev_size = 0;
-    fcs_compact_allocator_t derived_list_allocator;
+    fcs_batch_size prev_size = 0;
+    compact_allocator derived_list_allocator;
     fc_solve_compact_allocator_init(
         &(derived_list_allocator), &(thread->thread_meta_alloc));
     const_AUTO(out_fh, instance->common.out_fh);
@@ -117,14 +117,14 @@ static void *instance_run_solver_thread(void *const void_arg)
     TRACE("%s\n", "instance_run_solver_thread start");
 
     const_AUTO(coll, &(instance->colls_by_depth[instance->curr_depth]));
-    fcs_dbm_record_t *tokens[max_batch_size];
-    fcs_derived_state_t *derived_lists[max_batch_size];
+    fcs_dbm_record *tokens[max_batch_size];
+    fcs_derived_state *derived_lists[max_batch_size];
     while (TRUE)
     {
         /* First of all extract a batch of items. */
         fcs_lock_lock(&instance->common.storage_lock);
-        fcs_bool_t should_break = FALSE;
-        batch_size_t batch_size = 0;
+        bool should_break = FALSE;
+        fcs_batch_size batch_size = 0;
         if (prev_size > 0)
         {
             if (!(instance->common.queue_num_extracted_and_processed -=
@@ -142,9 +142,8 @@ static void *instance_run_solver_thread(void *const void_arg)
             {
                 for (; batch_size < max_batch_size; ++batch_size)
                 {
-                    if (fcs_offloading_queue__extract(
-                            &(coll->queue), (fcs_offloading_queue_item_t
-                                                    *)(&tokens[batch_size])))
+                    if (fcs_offloading_queue__extract(&(coll->queue),
+                            (offloading_queue_item *)(&tokens[batch_size])))
                     {
                         derived_lists[batch_size] = NULL;
                         instance_increment(instance);
@@ -179,7 +178,7 @@ static void *instance_run_solver_thread(void *const void_arg)
             continue;
         }
 
-        for (batch_size_t batch_i = 0; batch_i < batch_size; ++batch_i)
+        for (fcs_batch_size batch_i = 0; batch_i < batch_size; ++batch_i)
         {
             const_AUTO(token, tokens[batch_i]);
             /* Handle item. */
@@ -192,7 +191,7 @@ static void *instance_run_solver_thread(void *const void_arg)
                     &state, token, &derived_lists[batch_i],
                     &derived_list_recycle_bin, &derived_list_allocator, TRUE))
             {
-                fcs_dbm_queue_item_t physical_item;
+                fcs_dbm_queue_item physical_item;
                 physical_item.key = token->key;
                 fcs_lock_lock(&instance->common.storage_lock);
                 fcs_dbm__found_solution(
@@ -204,7 +203,7 @@ static void *instance_run_solver_thread(void *const void_arg)
         }
 
         /* Encode all the states. */
-        for (batch_size_t batch_i = 0; batch_i < batch_size; ++batch_i)
+        for (fcs_batch_size batch_i = 0; batch_i < batch_size; ++batch_i)
         {
             for (var_AUTO(derived_iter, derived_lists[batch_i]); derived_iter;
                  derived_iter = derived_iter->next)
@@ -222,7 +221,7 @@ static void *instance_run_solver_thread(void *const void_arg)
 #endif
         );
 
-        for (batch_size_t batch_i = 0; batch_i < batch_size; ++batch_i)
+        for (fcs_batch_size batch_i = 0; batch_i < batch_size; ++batch_i)
         {
             fcs_derived_state_list__recycle(
                 &derived_list_recycle_bin, &derived_lists[batch_i]);
@@ -240,32 +239,32 @@ thread_end:
 #include "depth_dbm_procs.h"
 
 static inline void instance_check_key(
-    fcs_dbm_solver_thread_t *const thread GCC_UNUSED,
-    fcs_dbm_solver_instance_t *const instance, const int key_depth,
-    fcs_encoded_state_buffer_t *const key, fcs_dbm_record_t *const parent,
+    dbm_solver_thread *const thread GCC_UNUSED,
+    dbm_solver_instance *const instance, const int key_depth,
+    fcs_encoded_state_buffer *const key, fcs_dbm_record *const parent,
     const unsigned char move GCC_UNUSED,
-    const fcs_which_moves_bitmask_t *const which_irreversible_moves_bitmask
+    const fcs_which_moves_bitmask *const which_irreversible_moves_bitmask
         GCC_UNUSED
 #ifdef FCS_DBM_CACHE_ONLY
     ,
-    const fcs_fcc_move_t *moves_to_parent
+    const fcs_fcc_move *moves_to_parent
 #endif
 )
 {
     const_AUTO(coll, &(instance->colls_by_depth[key_depth]));
-    fcs_dbm_record_t *token;
+    fcs_dbm_record *token;
 
     if ((token = cache_store__has_key(&coll->cache_store, key, parent)))
     {
 #ifndef FCS_DBM_WITHOUT_CACHES
-        fcs_cache_key_info_t *cache_key = cache_store__insert_key(
+        fcs_cache_key_info *cache_key = cache_store__insert_key(
             &(instance->cache_store), key, parent, moves_to_parent, move);
 #endif
 
         /* Now insert it into the queue. */
 
         fcs_offloading_queue__insert(
-            &(coll->queue), (const fcs_offloading_queue_item_t *)(&token));
+            &(coll->queue), (const offloading_queue_item *)(&token));
 
         ++instance->common.count_of_items_in_queue;
         ++instance->common.num_states_in_collection;
@@ -273,8 +272,8 @@ static inline void instance_check_key(
     }
 }
 
-static void instance_run_all_threads(fcs_dbm_solver_instance_t *const instance,
-    fcs_state_keyval_pair_t *const init_state, const size_t num_threads)
+static void instance_run_all_threads(dbm_solver_instance *const instance,
+    fcs_state_keyval_pair *const init_state, const size_t num_threads)
 {
     const_AUTO(threads,
         dbm__calc_threads(instance, init_state, num_threads, init_thread));
@@ -300,8 +299,8 @@ int main(int argc, char *argv[])
 {
     const char *out_filename = NULL;
     DECLARE_IND_BUF_T(init_indirect_stacks_buffer)
-    fcs_dbm_common_input_t inp = fcs_dbm_common_input_init;
-    batch_size_t max_batch_size = 1;
+    fcs_dbm_common_input inp = fcs_dbm_common_input_init;
+    fcs_batch_size max_batch_size = 1;
     const char *param;
 
     int real_arg;
@@ -313,7 +312,7 @@ int main(int argc, char *argv[])
         }
         else if ((param = TRY_PARAM("--batch-size")))
         {
-            max_batch_size = (batch_size_t)atol(param);
+            max_batch_size = (fcs_batch_size)atol(param);
             if (max_batch_size < 1)
             {
                 fc_solve_err("--batch-size must be at least 1.\n");
@@ -333,40 +332,36 @@ int main(int argc, char *argv[])
     {
         fc_solve_err("%s\n", "Junk arguments!");
     }
-    else if (real_arg == argc)
+    if (real_arg == argc)
     {
         fc_solve_err("%s\n", "No board specified.");
     }
     const_AUTO(num_threads, inp.num_threads);
 
     FILE *const out_fh = calc_out_fh(out_filename);
-    fcs_state_keyval_pair_t init_state;
+    fcs_state_keyval_pair init_state;
     read_state_from_file(inp.local_variant, argv[real_arg],
         &init_state PASS_IND_BUF_T(init_indirect_stacks_buffer));
     horne_prune__simple(inp.local_variant, &init_state);
 
     const_AUTO(local_variant, inp.local_variant);
-    fc_solve_delta_stater_t delta;
-    fc_solve_delta_stater_init(&delta, &init_state.s, STACKS_NUM, FREECELLS_NUM
-#ifndef FCS_FREECELL_ONLY
-        ,
-        CALC_SEQUENCES_ARE_BUILT_BY()
-#endif
-    );
+    fcs_delta_stater delta;
+    fc_solve_delta_stater_init(&delta, local_variant, &init_state.s, STACKS_NUM,
+        FREECELLS_NUM PASS_ON_NOT_FC_ONLY(CALC_SEQUENCES_ARE_BUILT_BY()));
 
 #define KEY_PTR() (key_ptr)
-    fcs_dbm_solver_instance_t instance;
+    dbm_solver_instance instance;
     instance_init(&instance, &inp, max_batch_size, out_fh);
 
-    fcs_encoded_state_buffer_t *const key_ptr = &(instance.common.first_key);
+    fcs_encoded_state_buffer *const key_ptr = &(instance.common.first_key);
     fcs_init_and_encode_state(&delta, local_variant, &init_state, KEY_PTR());
 
     /* The NULL parent_state_enc and move for indicating this is the
      * initial state. */
-    fcs_encoded_state_buffer_t parent_state_enc;
+    fcs_encoded_state_buffer parent_state_enc;
     fcs_init_encoded_state(&(parent_state_enc));
 
-    fcs_dbm_record_t *token;
+    fcs_dbm_record *token;
 #ifndef FCS_DBM_WITHOUT_CACHES
     cache_store__insert_key(
         &(instance.cache_store), KEY_PTR(), &parent_state_enc, NULL, '\0');
@@ -376,7 +371,7 @@ int main(int argc, char *argv[])
 #endif
 
     fcs_offloading_queue__insert(&(instance.colls_by_depth[0].queue),
-        (const fcs_offloading_queue_item_t *)(&token));
+        (const offloading_queue_item *)(&token));
     ++instance.common.num_states_in_collection;
     ++instance.common.count_of_items_in_queue;
 
