@@ -7,10 +7,8 @@
  *
  * Copyright (c) 2012 Shlomi Fish
  */
-/*
- * fcc_brfs.h - contains the perform_FCC_brfs() function to perform the
- * Breadth-first-search on the Fully-connected-component.
- */
+// fcc_brfs.h - contains the perform_FCC_brfs() function to perform the
+// Breadth-first-search on the Fully-connected-component.
 #pragma once
 
 #ifdef __cplusplus
@@ -20,7 +18,7 @@ extern "C" {
 #include <assert.h>
 #include "state.h"
 #include "meta_alloc.h"
-#include "fcs_enums.h"
+#include "freecell-solver/fcs_enums.h"
 #include "dbm_common.h"
 #include "delta_states.h"
 #include "dbm_calc_derived_iface.h"
@@ -31,33 +29,33 @@ extern "C" {
 
 typedef struct fcs_FCC_start_point_struct
 {
-    fcs_encoded_state_buffer_t enc_state;
-    fcs_fcc_moves_seq_t moves_seq;
+    fcs_encoded_state_buffer enc_state;
+    fcs_fcc_moves_seq moves_seq;
     struct fcs_FCC_start_point_struct *next;
-} fcs_FCC_start_point_t;
+} fcs_FCC_start_point;
 
 typedef struct
 {
-    fcs_FCC_start_point_t *list;
-    fcs_compact_allocator_t allocator;
-    fcs_FCC_start_point_t *recycle_bin;
-} fcs_FCC_start_points_list_t;
+    fcs_FCC_start_point *list;
+    compact_allocator allocator;
+    fcs_FCC_start_point *recycle_bin;
+} fcs_FCC_start_points_list;
 
 static int fc_solve_compare_encoded_states(const void *const void_a,
     const void *const void_b, void *const context GCC_UNUSED)
 {
-#define GET_PARAM(p) ((const fcs_encoded_state_buffer_t *)p)
+#define GET_PARAM(p) ((const fcs_encoded_state_buffer *)p)
     return memcmp(
         GET_PARAM(void_a), GET_PARAM(void_b), sizeof(*(GET_PARAM(void_a))));
 #undef GET_PARAM
 }
 
 static inline void fc_solve_fcc_release_moves_seq(
-    fcs_fcc_moves_seq_t *const moves_seq,
-    fcs_fcc_moves_seq_allocator_t *const moves_list_allocator)
+    fcs_fcc_moves_seq *const moves_seq,
+    fcs_fcc_moves_seq_allocator *const moves_list_allocator)
 {
-    fcs_fcc_moves_list_item_t *iter = moves_seq->moves_list;
-    fcs_fcc_moves_list_item_t *iter_next;
+    fcs_fcc_moves_list_item *iter = moves_seq->moves_list;
+    fcs_fcc_moves_list_item *iter_next;
 
     if (iter)
     {
@@ -78,14 +76,14 @@ static inline void fc_solve_fcc_release_moves_seq(
 }
 
 static inline void fc_solve__internal__copy_moves(
-    fcs_fcc_moves_seq_t *const moves_seq, int *const ptr_to_pos_in_moves,
-    fcs_fcc_moves_list_item_t ***const ptr_to_end_moves_iter,
+    fcs_fcc_moves_seq *const moves_seq, int *const ptr_to_pos_in_moves,
+    fcs_fcc_moves_list_item ***const ptr_to_end_moves_iter,
     const unsigned char extra_move,
-    fcs_fcc_moves_seq_allocator_t *const moves_list_allocator)
+    fcs_fcc_moves_seq_allocator *const moves_list_allocator)
 {
     int pos_in_moves = *ptr_to_pos_in_moves;
     var_AUTO(end_moves_iter, *ptr_to_end_moves_iter);
-    const fcs_fcc_moves_list_item_t *copy_from_iter = moves_seq->moves_list;
+    const fcs_fcc_moves_list_item *copy_from_iter = moves_seq->moves_list;
     const_SLOT(count, moves_seq);
 
     for (int copy_from_idx = 0; copy_from_idx < count;)
@@ -121,34 +119,33 @@ static inline void fc_solve__internal__copy_moves(
 }
 
 static inline dict_t *fcc_brfs_kaz_tree_create(
-    fcs_meta_compact_allocator_t *const meta_alloc,
-    void **const tree_recycle_bin)
+    meta_allocator *const meta_alloc, void **const tree_recycle_bin)
 {
     return fc_solve_kaz_tree_create(
         fc_solve_compare_encoded_states, NULL, meta_alloc, tree_recycle_bin);
 }
 
 static inline void fcc_brfs_add_key_to_tree(
-    dict_t *const tree, const fcs_encoded_state_buffer_t *const val)
+    dict_t *const tree, const fcs_encoded_state_buffer *const val)
 {
-    fcs_encoded_state_buffer_t *key_to_add =
+    fcs_encoded_state_buffer *key_to_add =
         fcs_compact_alloc_ptr(&(tree->dict_allocator), sizeof(*key_to_add));
     *key_to_add = *val;
     fc_solve_kaz_tree_alloc_insert(tree, key_to_add);
 }
 
-static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
+static void perform_FCC_brfs(const fcs_dbm_variant_type local_variant,
     /* The first state in the game, from which all states are encoded. */
-    fcs_state_keyval_pair_t *init_state,
+    fcs_state_keyval_pair *init_state,
     /* The start state. */
-    fcs_encoded_state_buffer_t start_state,
+    fcs_encoded_state_buffer start_state,
     /* The moves leading up to the state.
      * */
-    const fcs_fcc_moves_seq_t *const start_state_moves_seq,
+    const fcs_fcc_moves_seq *const start_state_moves_seq,
 #if 0
     /* [Output]: FCC start points.
      * */
-    fcs_FCC_start_points_list_t * fcc_start_points,
+    fcs_FCC_start_points_list * fcc_start_points,
     /* [Input/Output]: make sure the fcc_start_points don't repeat themselves,
      * in the same FCC-based-depth.
      * */
@@ -158,19 +155,18 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
      * [Output] a callback to add a point to the next_start_points,
      * and its context.
      */
-    fcs_bool_t (*add_start_point)(
-        const fcs_encoded_state_buffer_t *const enc_state,
-        const fcs_fcc_moves_seq_t *const start_state_moves_seq,
-        fcs_fcc_moves_seq_t *const after_start_moves_seq,
+    bool (*add_start_point)(const fcs_encoded_state_buffer *const enc_state,
+        const fcs_fcc_moves_seq *const start_state_moves_seq,
+        fcs_fcc_moves_seq *const after_start_moves_seq,
         const unsigned char extra_move, void *const context),
     void *add_start_point_context,
 #endif
     /* [Output]: Is the min_by_sorting new.
      * */
-    fcs_bool_t *is_min_by_sorting_new,
+    bool *is_min_by_sorting_new,
     /* [Output]: The min_by_sorting.
      * */
-    fcs_encoded_state_buffer_t *const min_by_sorting,
+    fcs_encoded_state_buffer *const min_by_sorting,
     /* [Input/Output]: The ${next}_depth_FCCs.DoesExist
      * (for the right depth based on the current depth and pruning.)
      * Of type Map{min_by_sorting => Bool Exists} DoesExist.
@@ -179,25 +175,25 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
     /* [Input/Output]: The LRU cache.
      * Of type <<LRU_Map{any_state_in_the_FCCs => Bool Exists} Cache>>
      * */
-    fcs_lru_cache_t *does_state_exist_in_any_FCC_cache,
+    fcs_lru_cache *does_state_exist_in_any_FCC_cache,
     /* [Output]: the number of new positions/states scanned in the FCC. If
      * it's not new, this will be set to zero (0). It includes the initial
      * position, but does not include the start points of the new FCC.
      * */
     long *const out_num_new_positions,
     /* [Input/Output]: the list allocator. */
-    fcs_fcc_moves_seq_allocator_t *const moves_list_allocator,
+    fcs_fcc_moves_seq_allocator *const moves_list_allocator,
     /* [Input/Output]: The meta allocator - needed to allocate and free
      * the compact allocators. */
-    fcs_meta_compact_allocator_t *const meta_alloc)
+    meta_allocator *const meta_alloc)
 {
     void *tree_recycle_bin = NULL;
-    fcs_dbm_queue_item_t *queue_head, *queue_tail, *queue_recycle_bin = NULL,
-                                                   *extracted_item;
-    fcs_derived_state_t *derived_list_recycle_bin = NULL, *next_derived_iter;
-    fcs_state_keyval_pair_t state;
-    fcs_bool_t running_min_was_assigned = FALSE;
-    fcs_encoded_state_buffer_t running_min = {{0}};
+    fcs_dbm_queue_item *queue_head, *queue_tail, *queue_recycle_bin = NULL,
+                                                 *extracted_item;
+    fcs_derived_state *derived_list_recycle_bin = NULL, *next_derived_iter;
+    fcs_state_keyval_pair state;
+    bool running_min_was_assigned = FALSE;
+    fcs_encoded_state_buffer running_min = {{0}};
     long num_new_positions = 0;
     DECLARE_IND_BUF_T(indirect_stacks_buffer)
 
@@ -212,25 +208,20 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
 #endif
 
     /* Initialize the allocators. */
-    fcs_compact_allocator_t queue_allocator, derived_list_allocator;
+    compact_allocator queue_allocator, derived_list_allocator;
     fc_solve_compact_allocator_init(&(queue_allocator), meta_alloc);
     fc_solve_compact_allocator_init(&(derived_list_allocator), meta_alloc);
 
     /* TODO : maybe pass delta_stater as an argument  */
-    fc_solve_delta_stater_t delta_stater;
-    fc_solve_delta_stater_init(
-        &delta_stater, &(init_state->s), STACKS_NUM, FREECELLS_NUM
-#ifndef FCS_FREECELL_ONLY
-        ,
-        FCS_SEQ_BUILT_BY_ALTERNATE_COLOR
-#endif
-    );
+    fcs_delta_stater delta_stater;
+    fc_solve_delta_stater_init(&delta_stater, FCS_DBM_VARIANT_2FC_FREECELL,
+        &(init_state->s), STACKS_NUM,
+        FREECELLS_NUM PASS_ON_NOT_FC_ONLY(FCS_SEQ_BUILT_BY_ALTERNATE_COLOR));
     dict_t *traversed_states =
         fcc_brfs_kaz_tree_create(meta_alloc, &tree_recycle_bin);
 
-    fcs_dbm_queue_item_t *new_item =
-        (fcs_dbm_queue_item_t *)fcs_compact_alloc_ptr(
-            &(queue_allocator), sizeof(*new_item));
+    fcs_dbm_queue_item *new_item = (fcs_dbm_queue_item *)fcs_compact_alloc_ptr(
+        &(queue_allocator), sizeof(*new_item));
     *new_item = (typeof(*new_item)){.key = start_state,
         .next = NULL,
         .moves_seq = {.count = 0, .moves_list = NULL}};
@@ -270,7 +261,7 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
         }
 
         /* Calculate the derived list. */
-        fcs_derived_state_t *derived_list = NULL;
+        fcs_derived_state *derived_list = NULL;
 
         /* Handle item. */
         fc_solve_delta_stater_decode_into_state(&delta_stater,
@@ -290,7 +281,7 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
         }
         else
         {
-            new_item = (fcs_dbm_queue_item_t *)fcs_compact_alloc_ptr(
+            new_item = (fcs_dbm_queue_item *)fcs_compact_alloc_ptr(
                 &(queue_allocator), sizeof(*new_item));
         }
 
@@ -298,7 +289,7 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
         for (var_AUTO(derived_iter, derived_list); derived_iter;
              derived_iter = next_derived_iter)
         {
-            const fcs_bool_t is_reversible =
+            const bool is_reversible =
                 (derived_iter->core_irreversible_moves_count == 0);
             fcs_init_and_encode_state(&delta_stater, local_variant,
                 &(derived_iter->state), &(new_item->key));
@@ -315,7 +306,7 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
                 if (is_reversible)
                 {
                     fcc_brfs_add_key_to_tree(traversed_states, &new_item->key);
-                    fcs_fcc_moves_list_item_t *moves_list,
+                    fcs_fcc_moves_list_item *moves_list,
                         **end_moves_iter = &moves_list;
                     /* Fill in the moves. */
                     int pos_in_moves = 0;
@@ -352,7 +343,7 @@ static void perform_FCC_brfs(const fcs_dbm_variant_type_t local_variant,
                 }
                 else
                 {
-                    new_item = (fcs_dbm_queue_item_t *)fcs_compact_alloc_ptr(
+                    new_item = (fcs_dbm_queue_item *)fcs_compact_alloc_ptr(
                         &(queue_allocator), sizeof(*new_item));
                 }
             }
@@ -391,22 +382,22 @@ free_resources:
 
 typedef struct
 {
-    fcs_FCC_start_points_list_t *next_start_points_list;
+    fcs_FCC_start_points_list *next_start_points_list;
     dict_t *do_next_fcc_start_points_exist;
-    fcs_fcc_moves_seq_allocator_t *moves_list_allocator;
-} add_start_point_context_t;
+    fcs_fcc_moves_seq_allocator *moves_list_allocator;
+} add_start_point_context;
 
 /*
  * Returns if already exist (the NOT of if the state is new).
  */
-static fcs_bool_t fc_solve_add_start_point_in_mem(
-    const fcs_encoded_state_buffer_t *const enc_state,
-    const fcs_fcc_moves_seq_t *const start_state_moves_seq,
-    fcs_fcc_moves_seq_t *const after_start_moves_seq,
+static bool fc_solve_add_start_point_in_mem(
+    const fcs_encoded_state_buffer *const enc_state,
+    const fcs_fcc_moves_seq *const start_state_moves_seq,
+    fcs_fcc_moves_seq *const after_start_moves_seq,
     const unsigned char extra_move, void *const void_context)
 {
-    add_start_point_context_t *const context =
-        (add_start_point_context_t *)void_context;
+    add_start_point_context *const context =
+        (add_start_point_context *)void_context;
     dict_t *const tree = context->do_next_fcc_start_points_exist;
 
     if (fc_solve_kaz_tree_lookup_value(tree, enc_state))
@@ -416,17 +407,17 @@ static fcs_bool_t fc_solve_add_start_point_in_mem(
 
     fcc_brfs_add_key_to_tree(tree, enc_state);
     /* Fill in the moves. */
-    fcs_fcc_moves_list_item_t *moves_list;
-    fcs_fcc_moves_list_item_t **end_moves_iter = &moves_list;
+    fcs_fcc_moves_list_item *moves_list;
+    fcs_fcc_moves_list_item **end_moves_iter = &moves_list;
     int pos_in_moves = 0;
     /*
      * TODO : optimise the loop so the data will be copied
      * in one go by jumps of FCS_FCC_NUM_MOVES_IN_ITEM
      * */
-    const fcs_fcc_moves_list_item_t *start_iter =
+    const fcs_fcc_moves_list_item *start_iter =
         start_state_moves_seq->moves_list;
     const int count_start_state_moves = start_state_moves_seq->count;
-    fcs_fcc_moves_seq_allocator_t *const moves_list_allocator =
+    fcs_fcc_moves_seq_allocator *const moves_list_allocator =
         context->moves_list_allocator;
     for (; pos_in_moves < count_start_state_moves;)
     {
@@ -447,9 +438,9 @@ static fcs_bool_t fc_solve_add_start_point_in_mem(
         &end_moves_iter, extra_move, moves_list_allocator);
 
     /* Enqueue the new FCC start point. */
-    fcs_FCC_start_points_list_t *const fcc_start_points =
+    fcs_FCC_start_points_list *const fcc_start_points =
         context->next_start_points_list;
-    fcs_FCC_start_point_t *new_start_point;
+    fcs_FCC_start_point *new_start_point;
     if (fcc_start_points->recycle_bin)
     {
         new_start_point = fcc_start_points->recycle_bin;
@@ -457,7 +448,7 @@ static fcs_bool_t fc_solve_add_start_point_in_mem(
     }
     else
     {
-        new_start_point = (fcs_FCC_start_point_t *)fcs_compact_alloc_ptr(
+        new_start_point = (fcs_FCC_start_point *)fcs_compact_alloc_ptr(
             &(fcc_start_points->allocator), sizeof(*new_start_point));
     }
     *new_start_point = (typeof(*new_start_point)){.enc_state = *enc_state,
