@@ -20,7 +20,7 @@ static const char encoding_table[] = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H',
     'X', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l',
     'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '0',
     '1', '2', '3', '4', '5', '6', '7', '8', '9', '+', '_'};
-static char decoding_table[256];
+static unsigned char decoding_table[256];
 static const int mod_table[] = {0, 2, 1};
 
 static inline void build_decoding_table(void)
