@@ -9,21 +9,20 @@
  */
 // google_hash.h - header file for Google's dense_hash_map as adapted
 // for Freecell Solver.
-
 #pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include "config.h"
+#include "fcs_conf.h"
 #include "rinutils.h"
 
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GOOGLE_DENSE_HASH)
 
-typedef void *fcs_states_google_hash_handle_t;
+typedef void *fcs_states_google_hash_handle;
 
-extern fcs_states_google_hash_handle_t fc_solve_states_google_hash_new(void);
+extern fcs_states_google_hash_handle fc_solve_states_google_hash_new(void);
 
 /*
  * Returns 0 if the key is new and the key/val pair was inserted.
@@ -32,22 +31,22 @@ extern fcs_states_google_hash_handle_t fc_solve_states_google_hash_new(void);
  * Returns 1 if the key is not new and *existing_key / *existing_val
  * was set to it.
  */
-extern fcs_bool_t fc_solve_states_google_hash_insert(
-    fcs_states_google_hash_handle_t hash, void *key, void **existing_key);
+extern bool fc_solve_states_google_hash_insert(
+    fcs_states_google_hash_handle hash, void *key, void **existing_key);
 
-void fc_solve_states_google_hash_free(fcs_states_google_hash_handle_t hash);
+void fc_solve_states_google_hash_free(fcs_states_google_hash_handle hash);
 
 extern void fc_solve_states_google_hash_foreach(
-    fcs_states_google_hash_handle_t hash,
-    fcs_bool_t (*should_delete_ptr)(void *key, void *context), void *context);
+    fcs_states_google_hash_handle hash,
+    bool (*should_delete_ptr)(void *key, void *context), void *context);
 
 #endif
 
 #if (FCS_STACK_STORAGE == FCS_STACK_STORAGE_GOOGLE_DENSE_HASH)
 
-typedef void *fcs_columns_google_hash_handle_t;
+typedef void *fcs_columns_google_hash_handle;
 
-extern fcs_columns_google_hash_handle_t fc_solve_columns_google_hash_new(void);
+extern fcs_columns_google_hash_handle fc_solve_columns_google_hash_new(void);
 
 /*
  * Returns 0 if the key is new and the key/val pair was inserted.
@@ -56,10 +55,10 @@ extern fcs_columns_google_hash_handle_t fc_solve_columns_google_hash_new(void);
  * Returns 1 if the key is not new and *existing_key / *existing_val
  * was set to it.
  */
-extern fcs_bool_t fc_solve_columns_google_hash_insert(
-    fcs_columns_google_hash_handle_t hash, void *key, void **existing_key);
+extern bool fc_solve_columns_google_hash_insert(
+    fcs_columns_google_hash_handle hash, void *key, void **existing_key);
 
-void fc_solve_columns_google_hash_free(fcs_columns_google_hash_handle_t hash);
+void fc_solve_columns_google_hash_free(fcs_columns_google_hash_handle hash);
 
 #endif
 
