@@ -7,17 +7,14 @@
  *
  * Copyright (c) 2000 Shlomi Fish
  */
-/*
- * indirect_buffer.h - declare the dll_ind_buf_t type.
- */
+// indirect_buffer.h - declare the dll_ind_buf type.
 #pragma once
-
-#include "config.h"
+#include "fcs_conf.h"
 
 #ifdef INDIRECT_STACK_STATES
-typedef char dll_ind_buf_t[MAX_NUM_STACKS << 7];
-#define DECLARE_IND_BUF_T(ident) dll_ind_buf_t ident;
-#define IND_BUF_T_PARAM(ident) , dll_ind_buf_t ident
+typedef char dll_ind_buf[MAX_NUM_STACKS << 7];
+#define DECLARE_IND_BUF_T(ident) dll_ind_buf ident;
+#define IND_BUF_T_PARAM(ident) , dll_ind_buf ident
 #define PASS_IND_BUF_T(ident) , ident
 #else
 #define DECLARE_IND_BUF_T(ident)
