@@ -36,13 +36,13 @@
     a guideline for the end-user.
 */
 
-const fcs_default_weights_t fc_solve_default_befs_weights = {
+static const fcs_default_weights fc_solve_default_befs_weights = {
     .weights = {0.5, 0, 0.3, 0, 0.2, 0}};
 
 static inline void soft_thread_clean_soft_dfs(
-    fc_solve_soft_thread_t *const soft_thread)
+    fcs_soft_thread *const soft_thread)
 {
-    fcs_soft_dfs_stack_item_t *const soft_dfs_info =
+    fcs_soft_dfs_stack_item *const soft_dfs_info =
         DFS_VAR(soft_thread, soft_dfs_info);
     // Check if a Soft-DFS-type scan was called in the first place
     if (!soft_dfs_info)
@@ -51,10 +51,10 @@ static inline void soft_thread_clean_soft_dfs(
     }
 
     // De-allocate the Soft-DFS specific stacks
-    const fcs_soft_dfs_stack_item_t *info_ptr = soft_dfs_info;
-    const fcs_soft_dfs_stack_item_t *const max_info_ptr =
+    const fcs_soft_dfs_stack_item *info_ptr = soft_dfs_info;
+    const fcs_soft_dfs_stack_item *const max_info_ptr =
         info_ptr + DFS_VAR(soft_thread, depth);
-    const fcs_soft_dfs_stack_item_t *const dfs_max_info_ptr =
+    const fcs_soft_dfs_stack_item *const dfs_max_info_ptr =
         info_ptr + DFS_VAR(soft_thread, dfs_max_depth);
 
     for (; info_ptr < max_info_ptr; ++info_ptr)
@@ -77,7 +77,7 @@ static inline void soft_thread_clean_soft_dfs(
 }
 
 extern void fc_solve_free_soft_thread_by_depth_move_array(
-    fc_solve_soft_thread_t *const soft_thread)
+    fcs_soft_thread *const soft_thread)
 {
     const_AUTO(
         by_depth_moves, soft_thread->by_depth_moves_order.by_depth_moves);
@@ -109,8 +109,8 @@ static inline void accumulate_tests_by_ptr(
     }
 }
 
-static inline void soft_thread_run_cb(fc_solve_soft_thread_t *const soft_thread,
-    const fcs_foreach_st_callback_choice_t callback_choice, void *const context)
+static inline void soft_thread_run_cb(fcs_soft_thread *const soft_thread,
+    const foreach_st_callback_choice callback_choice, void *const context)
 {
     switch (callback_choice)
     {
@@ -141,15 +141,15 @@ static inline void soft_thread_run_cb(fc_solve_soft_thread_t *const soft_thread,
     }
 }
 
-void fc_solve_foreach_soft_thread(fc_solve_instance_t *const instance,
-    const fcs_foreach_st_callback_choice_t callback_choice, void *const context)
+void fc_solve_foreach_soft_thread(fcs_instance *const instance,
+    const foreach_st_callback_choice callback_choice, void *const context)
 {
 #ifdef FCS_SINGLE_HARD_THREAD
     const int_fast32_t num_soft_threads =
         instance->hard_thread.num_soft_threads;
     for (int_fast32_t st_idx = 0; st_idx <= num_soft_threads; ++st_idx)
     {
-        fc_solve_soft_thread_t *soft_thread;
+        fcs_soft_thread *soft_thread;
         if (st_idx < num_soft_threads)
         {
             soft_thread = &(instance->hard_thread.soft_threads[st_idx]);
@@ -170,7 +170,7 @@ void fc_solve_foreach_soft_thread(fc_solve_instance_t *const instance,
     for (uint_fast32_t ht_idx = 0; ht_idx <= instance->num_hard_threads;
          ++ht_idx)
     {
-        fc_solve_hard_thread_t *hard_thread;
+        fcs_hard_thread *hard_thread;
         if (ht_idx < instance->num_hard_threads)
         {
             hard_thread = &(instance->hard_threads[ht_idx]);
@@ -197,10 +197,10 @@ void fc_solve_foreach_soft_thread(fc_solve_instance_t *const instance,
 static inline
 #endif
     void
-    fc_solve_init_soft_thread(fc_solve_hard_thread_t *const hard_thread,
-        fc_solve_soft_thread_t *const soft_thread)
+    fc_solve_init_soft_thread(
+        fcs_hard_thread *const hard_thread, fcs_soft_thread *const soft_thread)
 {
-    *soft_thread = (fc_solve_soft_thread_t){
+    *soft_thread = (fcs_soft_thread){
         .hard_thread = hard_thread,
         .id = (HT_INSTANCE(hard_thread)->next_soft_thread_id)++,
         .method_specific =
@@ -273,9 +273,9 @@ static inline
 
 void fc_solve_instance__init_hard_thread(
 #ifndef FCS_SINGLE_HARD_THREAD
-    fc_solve_instance_t *const instance,
+    fcs_instance *const instance,
 #endif
-    fc_solve_hard_thread_t *const hard_thread)
+    fcs_hard_thread *const hard_thread)
 {
 #ifndef FCS_SINGLE_HARD_THREAD
     hard_thread->instance = instance;
@@ -306,33 +306,6 @@ void fc_solve_instance__init_hard_thread(
 #endif
 }
 
-#ifdef INDIRECT_STACK_STATES
-
-#if (FCS_STACK_STORAGE == FCS_STACK_STORAGE_GLIB_HASH)
-static guint fc_solve_glib_hash_stack_hash_function(gconstpointer key)
-{
-    guint hash_value_int = 0;
-    /* This hash function was ripped from the Perl source code.
-     * (It is not derived work however). */
-    const char *s_ptr = (char *)key;
-    const char *const s_end = s_ptr + fcs_col_len((fcs_card_t *)key) + 1;
-    while (s_ptr < s_end)
-    {
-        hash_value_int += (hash_value_int << 5) + *(s_ptr++);
-    }
-    hash_value_int += (hash_value_int >> 5);
-
-    return hash_value_int;
-}
-
-static gint fc_solve_glib_hash_stack_compare(gconstpointer a, gconstpointer b)
-{
-    return !(fc_solve_stack_compare_for_comparison(a, b));
-}
-#endif
-
-#endif
-
 typedef struct
 {
     int idx;
@@ -341,7 +314,7 @@ typedef struct
         FREECELL,
         COLUMN
     } type;
-} find_card_ret_t;
+} find_card_ret;
 
 // This function traces the solution from the final state down to the initial
 // state
@@ -349,7 +322,7 @@ typedef struct
 
 #ifndef FCS_DISABLE_PATSOLVE
 static inline int find_empty_col(
-    const fcs_state_t *const dynamic_state STACKS_NUM__ARG)
+    const fcs_state *const dynamic_state STACKS_NUM__ARG)
 {
     for (size_t i = 0; i < STACKS_NUM__VAL; ++i)
     {
@@ -362,8 +335,8 @@ static inline int find_empty_col(
     return -1;
 }
 
-static inline int find_col_card(const fcs_state_t *const dynamic_state,
-    const fcs_card_t needle STACKS_NUM__ARG)
+static inline int find_col_card(
+    const fcs_state *const dynamic_state, const fcs_card needle STACKS_NUM__ARG)
 {
     for (size_t i = 0; i < STACKS_NUM__VAL; ++i)
     {
@@ -378,8 +351,9 @@ static inline int find_col_card(const fcs_state_t *const dynamic_state,
     return -1;
 }
 
-static inline int find_fc_card(const fcs_state_t *const dynamic_state,
-    const fcs_card_t needle FREECELLS_NUM__ARG)
+#if MAX_NUM_FREECELLS > 0
+static inline int find_fc_card(const fcs_state *const dynamic_state,
+    const fcs_card needle FREECELLS_NUM__ARG)
 {
     for (size_t dest = 0; dest < FREECELLS_NUM__VAL; ++dest)
     {
@@ -391,30 +365,32 @@ static inline int find_fc_card(const fcs_state_t *const dynamic_state,
 
     return -1;
 }
+#endif
 
-static inline find_card_ret_t find_card_src_string(
-    const fcs_state_t *const dynamic_state,
-    const fcs_card_t needle FREECELLS_AND_STACKS_ARGS())
+static inline find_card_ret find_card_src_string(
+    const fcs_state *const dynamic_state,
+    const fcs_card needle FREECELLS_AND_STACKS_ARGS())
 {
     const int src_col_idx =
         find_col_card(dynamic_state, needle PASS_STACKS(STACKS_NUM__VAL));
+#if MAX_NUM_FREECELLS > 0
     if (src_col_idx < 0)
     {
-        return (find_card_ret_t){
-            .idx = (find_fc_card(
-                dynamic_state, needle PASS_FREECELLS(FREECELLS_NUM__VAL))),
+        return (find_card_ret){.idx = (find_fc_card(dynamic_state,
+                                   needle PASS_FREECELLS(FREECELLS_NUM__VAL))),
             .type = FREECELL};
     }
     else
+#endif
     {
-        return (find_card_ret_t){.idx = src_col_idx, .type = COLUMN};
+        return (find_card_ret){.idx = src_col_idx, .type = COLUMN};
     }
 }
 #endif
 
-extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
+extern void fc_solve_trace_solution(fcs_instance *const instance)
 {
-    fcs_internal_move_t canonize_move = fc_solve_empty_move;
+    fcs_internal_move canonize_move = fc_solve_empty_move;
     fcs_int_move_set_type(canonize_move, FCS_MOVE_TYPE_CANONIZE);
 
     instance_free_solution_moves(instance);
@@ -428,12 +404,12 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
     const_SLOT(solving_soft_thread, instance);
     if (solving_soft_thread->super_method_type == FCS_SUPER_METHOD_PATSOLVE)
     {
-        fcs_state_locs_struct_t locs;
+        fcs_state_locs_struct locs;
         fc_solve_init_locs(&(locs));
         const_SLOT(pats_scan, solving_soft_thread);
         var_AUTO(num_moves, pats_scan->num_moves_to_win);
 
-        fcs_state_keyval_pair_t s_and_info;
+        fcs_state_keyval_pair s_and_info;
         DECLARE_IND_BUF_T(indirect_stacks_buffer)
         FCS_STATE__DUP_keyval_pair(s_and_info, (instance->state_copy));
 
@@ -444,7 +420,7 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
         const int freecells_num = INSTANCE_FREECELLS_NUM;
 #endif
 
-        fcs_state_t *const s = &(s_and_info.s);
+        fcs_state *const s = &(s_and_info.s);
 #ifdef INDIRECT_STACK_STATES
         for (int i = 0; i < STACKS_NUM__VAL; ++i)
         {
@@ -459,10 +435,11 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
         var_AUTO(move_ptr, pats_scan->moves_to_win);
         for (size_t i = 0; i < num_moves; ++i, ++move_ptr)
         {
-            const fcs_card_t card = move_ptr->card;
-            fcs_internal_move_t out_move = fc_solve_empty_move;
+            const fcs_card card = move_ptr->card;
+            fcs_internal_move out_move = fc_solve_empty_move;
             switch (move_ptr->totype)
             {
+#if MAX_NUM_FREECELLS > 0
             case FCS_PATS__TYPE_FREECELL:
             {
                 int src_col_idx;
@@ -495,11 +472,12 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
                 }
             }
             break;
+#endif
             case FCS_PATS__TYPE_FOUNDATION:
             {
-                const find_card_ret_t src = find_card_src_string(
-                    &(s_and_info.s), card PASS_FREECELLS(FREECELLS_NUM__VAL)
-                                         PASS_STACKS(STACKS_NUM__VAL));
+                const find_card_ret src = find_card_src_string(&(s_and_info.s),
+                    card PASS_FREECELLS(FREECELLS_NUM__VAL)
+                        PASS_STACKS(STACKS_NUM__VAL));
                 if (src.type == FREECELL)
                 {
                     fcs_int_move_set_type(
@@ -516,8 +494,8 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
             break;
             default:
             {
-                const fcs_card_t dest_card = move_ptr->destcard;
-                const find_card_ret_t src = find_card_src_string(s,
+                const fcs_card dest_card = move_ptr->destcard;
+                const find_card_ret src = find_card_src_string(s,
                     card PASS_FREECELLS(FREECELLS_NUM__VAL)
                         PASS_STACKS(STACKS_NUM__VAL));
                 if (src.type == FREECELL)
@@ -550,7 +528,7 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
     else
 #endif
     {
-        fcs_collectible_state_t *s1 = instance->final_state;
+        fcs_collectible_state *s1 = instance->final_state;
 
         /* Retrace the step from the current state to its parents */
         while (FCS_S_PARENT(s1) != NULL)
@@ -563,8 +541,8 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
             fcs_move_stack_push(solution_moves_ptr, canonize_move);
 
             /* Merge the move stack */
-            const fcs_move_stack_t *const stack = FCS_S_MOVES_TO_PARENT(s1);
-            const fcs_internal_move_t *const moves = stack->moves;
+            const fcs_move_stack *const stack = FCS_S_MOVES_TO_PARENT(s1);
+            const fcs_internal_move *const moves = stack->moves;
             for (int move_idx = stack->num_moves - 1; move_idx >= 0; --move_idx)
             {
                 fcs_move_stack_push(solution_moves_ptr, moves[move_idx]);
@@ -582,7 +560,7 @@ extern void fc_solve_trace_solution(fc_solve_instance_t *const instance)
 
 // This function should be called after the user has retrieved the results
 // generated by the scan, as it will destroy them.
-void fc_solve_finish_instance(fc_solve_instance_t *const instance)
+void fc_solve_finish_instance(fcs_instance *const instance)
 {
 // De-allocate the state collection
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_LIBREDBLACK_TREE)
@@ -655,8 +633,7 @@ void fc_solve_finish_instance(fc_solve_instance_t *const instance)
         instance, FOREACH_SOFT_THREAD_CLEAN_SOFT_DFS, NULL);
 }
 
-fc_solve_soft_thread_t *fc_solve_new_soft_thread(
-    fc_solve_hard_thread_t *const hard_thread)
+fcs_soft_thread *fc_solve_new_soft_thread(fcs_hard_thread *const hard_thread)
 {
     if (HT_INSTANCE(hard_thread)->next_soft_thread_id == MAX_NUM_SCANS)
     {
@@ -667,7 +644,7 @@ fc_solve_soft_thread_t *fc_solve_new_soft_thread(
         SREALLOC(HT_FIELD(hard_thread, soft_threads),
             HT_FIELD(hard_thread, num_soft_threads) + 1);
 
-    fc_solve_soft_thread_t *ret;
+    fcs_soft_thread *ret;
 
     fc_solve_init_soft_thread(hard_thread,
         (ret = &(HT_FIELD(hard_thread,
