@@ -7,8 +7,8 @@
  *
  * Copyright (c) 2000 Shlomi Fish
  */
-// instance.h - header file of fc_solve_instance_t / fc_solve_hard_thread_t /
-// fc_solve_soft_thread_t .
+// instance.h - header file of fcs_instance / fcs_hard_thread /
+// fcs_soft_thread .
 #pragma once
 
 #ifdef __cplusplus
@@ -18,8 +18,8 @@ extern "C" {
 #include <math.h>
 
 #include "move.h"
-#include "fcs_enums.h"
-#include "fcs_user.h"
+#include "freecell-solver/fcs_enums.h"
+#include "freecell-solver/fcs_user.h"
 #include "rate_state.h"
 #include "indirect_buffer.h"
 #include "rand.h"
@@ -93,19 +93,18 @@ extern "C" {
 typedef struct
 {
     char col, height;
-} fcs_pos_by_rank_t;
+} fcs_pos_by_rank;
 
 #ifndef FCS_DISABLE_SIMPLE_SIMON
 #define FCS_SS_POS_BY_RANK_WIDTH (FCS_RANK_KING + 1)
 #define FCS_SS_POS_BY_RANK_LEN (FCS_SS_POS_BY_RANK_WIDTH * 4)
 #define FCS_BOTH__POS_BY_RANK__SIZE                                            \
-    (max(FCS_SS_POS_BY_RANK_LEN * sizeof(fcs_pos_by_rank_t),                   \
-        FCS_POS_BY_RANK_LEN))
+    (max(FCS_SS_POS_BY_RANK_LEN * sizeof(fcs_pos_by_rank), FCS_POS_BY_RANK_LEN))
 #else
 #define FCS_BOTH__POS_BY_RANK__SIZE FCS_POS_BY_RANK_LEN
 #endif
 
-typedef int8_t fcs__positions_by_rank_t[FCS_BOTH__POS_BY_RANK__SIZE];
+typedef int8_t fcs__positions_by_rank[FCS_BOTH__POS_BY_RANK__SIZE];
 
 /*
  * This is a linked list item that is used to implement a queue for the BFS
@@ -113,9 +112,9 @@ typedef int8_t fcs__positions_by_rank_t[FCS_BOTH__POS_BY_RANK__SIZE];
  * */
 typedef struct fcs_states_linked_list_item_struct
 {
-    fcs_collectible_state_t *s;
+    fcs_collectible_state *s;
     struct fcs_states_linked_list_item_struct *next;
-} fcs_states_linked_list_item_t;
+} fcs_states_linked_list_item;
 
 /*
  * Declare these structures because they will be used within
@@ -125,18 +124,27 @@ struct fc_solve_hard_thread_struct;
 struct fc_solve_soft_thread_struct;
 struct fc_solve_instance_struct;
 
-typedef void (*fc_solve_solve_for_state_move_func_t)(
-    struct fc_solve_soft_thread_struct *, fcs_kv_state_t,
-    fcs_derived_states_list_t *);
+typedef void (*fc_solve_solve_for_state_move_func)(
+    struct fc_solve_soft_thread_struct *, fcs_kv_state,
+    fcs_derived_states_list *);
 
 #ifdef FCS_SINGLE_HARD_THREAD
-typedef struct fc_solve_instance_struct fc_solve_hard_thread_t;
+#define HT_FIELD(ht, field) (ht)->hard_thread.field
+#define HT_INSTANCE(hard_thread) (hard_thread)
+#define INST_HT0(instance) ((instance)->hard_thread)
+#define NUM_CHECKED_STATES (HT_INSTANCE(hard_thread)->i__num_checked_states)
+typedef struct fc_solve_instance_struct fcs_hard_thread;
+extern void fc_solve_init_soft_thread(fcs_hard_thread *const hard_thread,
+    struct fc_solve_soft_thread_struct *const soft_thread);
 #else
-typedef struct fc_solve_hard_thread_struct fc_solve_hard_thread_t;
+#define HT_FIELD(hard_thread, field) (hard_thread)->field
+#define HT_INSTANCE(hard_thread) ((hard_thread)->instance)
+#define INST_HT0(instance) ((instance)->hard_threads[0])
+#define NUM_CHECKED_STATES HT_FIELD(hard_thread, ht__num_checked_states)
+typedef struct fc_solve_hard_thread_struct fcs_hard_thread;
 #endif
-
-extern fcs_bool_t fc_solve_check_and_add_state(
-    fc_solve_hard_thread_t *, fcs_kv_state_t *, fcs_kv_state_t *);
+extern bool fc_solve_check_and_add_state(
+    fcs_hard_thread *, fcs_kv_state *, fcs_kv_state *);
 
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
 extern guint fc_solve_hash_function(gconstpointer key);
@@ -146,51 +154,52 @@ extern guint fc_solve_hash_function(gconstpointer key);
 /* HT_LOOP == hard threads' loop - macros to abstract it. */
 #ifdef FCS_SINGLE_HARD_THREAD
 
-#define HT_LOOP_START() fc_solve_hard_thread_t *const hard_thread = instance;
+#define HT_LOOP_START() fcs_hard_thread *const hard_thread = instance;
 
 #else
 #define HT_LOOP_START()                                                        \
-    fc_solve_hard_thread_t *hard_thread = instance->hard_threads;              \
-    fc_solve_hard_thread_t *const end_hard_thread =                            \
+    fcs_hard_thread *hard_thread = instance->hard_threads;                     \
+    fcs_hard_thread *const end_hard_thread =                                   \
         hard_thread + instance->num_hard_threads;                              \
     for (; hard_thread < end_hard_thread; ++hard_thread)
 #endif
 
 /* ST_LOOP == soft threads' loop - macros to abstract it. */
 #define ST_LOOP_START()                                                        \
-    fc_solve_soft_thread_t *const ht_soft_threads =                            \
+    fcs_soft_thread *const ht_soft_threads =                                   \
         HT_FIELD(hard_thread, soft_threads);                                   \
-    fc_solve_soft_thread_t *soft_thread = ht_soft_threads;                     \
-    fc_solve_soft_thread_t *const end_soft_thread =                            \
+    fcs_soft_thread *soft_thread = ht_soft_threads;                            \
+    fcs_soft_thread *const end_soft_thread =                                   \
         ht_soft_threads + HT_FIELD(hard_thread, num_soft_threads);             \
     for (; soft_thread < end_soft_thread; ++soft_thread)
 #define MOVES_GROW_BY 16
 
 typedef struct
 {
-    double weights[FCS_NUM_BEFS_WEIGHTS];
-} fcs_default_weights_t;
+    fc_solve_weighting_float weights[FCS_NUM_BEFS_WEIGHTS];
+} fcs_default_weights;
 typedef struct
 {
-    fcs_bool_t should_go_over_stacks;
-    double max_sequence_move_factor, cards_under_sequences_factor,
-        seqs_over_renegade_cards_factor, depth_factor,
-        num_cards_not_on_parents_factor;
+    bool should_go_over_stacks;
+    fc_solve_weighting_float max_sequence_move_factor,
+        cards_under_sequences_factor, seqs_over_renegade_cards_factor,
+        depth_factor, num_cards_not_on_parents_factor;
 
-    double num_cards_out_lookup_table[14];
+    fc_solve_weighting_float num_cards_out_lookup_table[14];
     // The BeFS weights of the different BeFS tests. Those
     // weights determine the commulative priority of the state.
-    fcs_default_weights_t befs_weights;
-} fc_solve_state_weighting_t;
+    fcs_default_weights befs_weights;
+} fcs_state_weighting;
 
-typedef enum {
+typedef enum
+{
     FCS_NO_SHUFFLING,
     FCS_RAND,
     FCS_WEIGHTING,
 } fcs_moves_group_kind;
 
 typedef union {
-    fc_solve_solve_for_state_move_func_t f;
+    fc_solve_solve_for_state_move_func f;
     uint_fast32_t idx;
 } fcs_move_func;
 
@@ -199,7 +208,7 @@ typedef struct
     fcs_move_func *move_funcs;
     uint_fast32_t num;
     fcs_moves_group_kind shuffling_type;
-    fc_solve_state_weighting_t weighting;
+    fcs_state_weighting weighting;
 } fcs_moves_group;
 
 typedef struct
@@ -222,8 +231,8 @@ typedef struct
 #ifdef FCS_RCS_STATES
 struct fcs_cache_key_info_struct
 {
-    const fcs_collectible_state_t *val_ptr;
-    fcs_state_t key;
+    const fcs_collectible_state *val_ptr;
+    fcs_state key;
     /* lower_pri and higher_pri form a doubly linked list.
      *
      * pri == priority.
@@ -231,7 +240,7 @@ struct fcs_cache_key_info_struct
     struct fcs_cache_key_info_struct *lower_pri, *higher_pri;
 };
 
-typedef struct fcs_cache_key_info_struct fcs_cache_key_info_t;
+typedef struct fcs_cache_key_info_struct fcs_cache_key_info;
 
 typedef struct
 {
@@ -242,29 +251,26 @@ typedef struct
 #else
 #error Unknown FCS_RCS_CACHE_STORAGE
 #endif
-    fcs_compact_allocator_t states_values_to_keys_allocator;
+    compact_allocator states_values_to_keys_allocator;
     fcs_int_limit_t count_elements_in_cache, max_num_elements_in_cache;
 
-    fcs_cache_key_info_t *lowest_pri, *highest_pri, *recycle_bin;
-} fcs_lru_cache_t;
+    fcs_cache_key_info *lowest_pri, *highest_pri, *recycle_bin;
+} fcs_lru_cache;
 
 #endif
 
 #ifndef FCS_WITHOUT_ITER_HANDLER
-typedef void *fcs_instance_debug_iter_output_context_t;
-
-typedef void (*fcs_instance_debug_iter_output_func_t)(
-    fcs_instance_debug_iter_output_context_t, fcs_int_limit_t, int, void *,
-    fcs_kv_state_t *, fcs_int_limit_t);
+typedef void (*instance_debug_iter_output_func)(
+    void *, fcs_int_limit_t, int, void *, fcs_kv_state *, fcs_int_limit_t);
 #endif
 
-typedef struct fc_solve_soft_thread_struct fc_solve_soft_thread_t;
-typedef struct fc_solve_instance_struct fc_solve_instance_t;
+typedef struct fc_solve_soft_thread_struct fcs_soft_thread;
+typedef struct fc_solve_instance_struct fcs_instance;
 
 struct fc_solve_hard_thread_struct
 {
 #ifndef FCS_SINGLE_HARD_THREAD
-    fc_solve_instance_t *instance;
+    fcs_instance *instance;
 #endif
 
     struct fc_solve_soft_thread_struct *soft_threads;
@@ -293,14 +299,14 @@ struct fc_solve_hard_thread_struct
      * This is the mechanism used to allocate memory for stacks, states
      * and move stacks.
      * */
-    fcs_compact_allocator_t allocator;
+    compact_allocator allocator;
 
 #ifdef FCS_WITH_MOVES
     /*
      * This is a move stack that is used and re-used by the
      * moves functions of this hard thread
      * */
-    fcs_move_stack_t reusable_move_stack;
+    fcs_move_stack reusable_move_stack;
 #endif
 
     /*
@@ -317,7 +323,7 @@ struct fc_solve_hard_thread_struct
     const fc_solve_prelude_item *prelude;
 #endif
 
-    fcs_bool_t allocated_from_list;
+    bool allocated_from_list;
     int_fast32_t num_soft_threads;
 
     /*
@@ -337,47 +343,48 @@ struct fc_solve_hard_thread_struct
 typedef struct
 {
     int idx;
-    pq_rating_t rating;
-} fcs_rating_with_index_t;
+    pq_rating rating;
+} rating_with_index;
 
 typedef struct
 {
-    fcs_collectible_state_t *state;
-    fcs_derived_states_list_t derived_states_list;
+    fcs_collectible_state *state;
+    fcs_derived_states_list derived_states_list;
     size_t move_func_list_idx;
     size_t current_state_index;
     size_t move_func_idx;
     size_t derived_states_random_indexes_max_size;
-    fcs_rating_with_index_t *derived_states_random_indexes;
-    fcs__positions_by_rank_t positions_by_rank;
-    fcs_game_limit_t num_vacant_stacks;
-    fcs_game_limit_t num_vacant_freecells;
-} fcs_soft_dfs_stack_item_t;
+    rating_with_index *derived_states_random_indexes;
+    fcs__positions_by_rank positions_by_rank;
+    fcs_game_limit num_vacant_stacks;
+    fcs_game_limit num_vacant_freecells;
+} fcs_soft_dfs_stack_item;
 
 typedef struct
 {
     ssize_t max_depth;
     fcs_moves_order move_funcs;
-} fcs_moves_by_depth_unit_t;
+} moves_by_depth_unit;
 
 typedef struct
 {
     size_t num_units;
-    fcs_moves_by_depth_unit_t *by_depth_units;
+    moves_by_depth_unit *by_depth_units;
 } fcs_moves_by_depth_array;
 
-typedef enum {
+typedef enum
+{
     FCS_SUPER_METHOD_DFS,
     FCS_SUPER_METHOD_BEFS_BRFS,
 #ifndef FCS_DISABLE_PATSOLVE
     FCS_SUPER_METHOD_PATSOLVE,
 #endif
-} fcs_super_method_type_t;
+} fcs_super_method_type;
 
 struct fc_solve__patsolve_thread_struct;
 struct fc_solve_soft_thread_struct
 {
-    fc_solve_hard_thread_t *hard_thread;
+    fcs_hard_thread *hard_thread;
 
     /*
      * The ID of the soft thread inside the instance.
@@ -393,7 +400,7 @@ struct fc_solve_soft_thread_struct
     } by_depth_moves_order;
 
     /* The super-method type - can be  */
-    fcs_super_method_type_t super_method_type;
+    fcs_super_method_type super_method_type;
 
     struct
     {
@@ -405,7 +412,7 @@ struct fc_solve_soft_thread_struct
             ssize_t dfs_max_depth;
 
             /*
-             * Soft-DFS uses a stack of fcs_soft_dfs_stack_item_t s.
+             * Soft-DFS uses a stack of fcs_soft_dfs_stack_item s.
              *
              * derived_states_list - a list of states to be checked next.
              * Not all of them will be checked because it is possible that
@@ -425,7 +432,7 @@ struct fc_solve_soft_thread_struct
              * num_vacant_freecells - ditto for the freecells.
              *
              * */
-            fcs_soft_dfs_stack_item_t *soft_dfs_info;
+            fcs_soft_dfs_stack_item *soft_dfs_info;
 
             /* The depth of the DFS stacks */
             ssize_t depth;
@@ -434,7 +441,7 @@ struct fc_solve_soft_thread_struct
              * A pseudo-random number generator for use in the random-DFS
              * scan
              * */
-            fcs_rand_t rand_gen;
+            fcs_rand_gen rand_gen;
 
             /*
              * The initial seed of this random number generator
@@ -448,7 +455,7 @@ struct fc_solve_soft_thread_struct
         } soft_dfs;
         struct
         {
-            fcs__positions_by_rank_t befs_positions_by_rank;
+            fcs__positions_by_rank befs_positions_by_rank;
             fcs_move_func *moves_list, *moves_list_end;
             struct
             {
@@ -458,43 +465,43 @@ struct fc_solve_soft_thread_struct
                      * A linked list that serves as the queue for the BFS
                      * scan.
                      * */
-                    fcs_states_linked_list_item_t *bfs_queue;
+                    fcs_states_linked_list_item *bfs_queue;
                     /*
                      * The last item in the linked list, so new items can be
                      * added at
                      * it, thus making it a queue.
                      * */
-                    fcs_states_linked_list_item_t *bfs_queue_last_item;
+                    fcs_states_linked_list_item *bfs_queue_last_item;
                     /*
                      * A linked list of items that were freed from
                      * the queue and should be reused before allocating new
                      * items.
                      * */
-                    fcs_states_linked_list_item_t *recycle_bin;
+                    fcs_states_linked_list_item *recycle_bin;
                 } brfs;
                 struct
                 {
                     /*
                      * The priority queue of the BeFS scan
                      * */
-                    pri_queue_t pqueue;
-                    fc_solve_state_weighting_t weighting;
+                    pri_queue pqueue;
+                    fcs_state_weighting weighting;
                 } befs;
             } meth;
             /*
              * The first state to be checked by the scan. It is a kind of
              * bootstrap for the algorithm.
              * */
-            fcs_collectible_state_t *first_state_to_check;
+            fcs_collectible_state *first_state_to_check;
         } befs;
     } method_specific;
 
-    fcs_bool_t FCS_SOFT_THREAD_IS_FINISHED, FCS_SOFT_THREAD_INITIALIZED,
+    bool FCS_SOFT_THREAD_IS_FINISHED, FCS_SOFT_THREAD_INITIALIZED,
         FCS_SOFT_THREAD_IS_A_COMPLETE_SCAN;
 
     // The numbers of vacant stacks and freecells in the current state - is
     // read by the move functions in freecell.c .
-    fcs_game_limit_t num_vacant_stacks, num_vacant_freecells;
+    fcs_game_limit num_vacant_stacks, num_vacant_freecells;
 
     /*
      * The number of iterations with which to process this scan
@@ -512,7 +519,7 @@ struct fc_solve_soft_thread_struct
      * This variable is temporary - there should be a better pruning
      * abstraction with several optional prunes.
      * */
-    fcs_bool_t enable_pruning;
+    bool enable_pruning;
 #endif
 
 #ifndef FCS_DISABLE_PATSOLVE
@@ -524,8 +531,8 @@ struct fc_solve_soft_thread_struct
     /*
      * Differentiates between SOFT_DFS and RANDOM_DFS.
      * */
-    fcs_bool_t master_to_randomize;
-    fcs_bool_t is_befs
+    bool master_to_randomize;
+    bool is_befs
 #ifdef FCS_WITH_MOVES
         ,
         is_optimize_scan
@@ -537,10 +544,10 @@ struct fc_solve_instance_struct
 {
 // The parameters of the game - see the declaration of fcs_game_type_params_t .
 #ifndef FCS_FREECELL_ONLY
-    fcs_game_type_params_t game_params;
+    fcs_game_type_params game_params;
 #ifndef FCS_DISABLE_PATSOLVE
-    fcs_card_t game_variant_suit_mask;
-    fcs_card_t game_variant_desired_suit_value;
+    fcs_card game_variant_suit_mask;
+    fcs_card game_variant_desired_suit_value;
 #endif
 #endif
 
@@ -566,7 +573,7 @@ struct fc_solve_instance_struct
     fcs_int_limit_t effective_trim_states_in_collection_from;
 #endif
 #endif
-    fc_solve_seq_cards_power_type_t initial_cards_under_sequences_value;
+    fcs_seq_cards_power_type initial_cards_under_sequences_value;
 /*
  * tree is the balanced binary tree that is used to store and index
  * the checked states.
@@ -577,7 +584,7 @@ struct fc_solve_instance_struct
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_JUDY)
     Pvoid_t judy_array;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_LIBAVL2_TREE)
-    fcs_libavl2_states_tree_table_t *tree;
+    fcs_libavl2_states_tree_table *tree;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_TREE)
     GTree *tree;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_KAZ_TREE)
@@ -591,9 +598,9 @@ struct fc_solve_instance_struct
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
     GHashTable *hash;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_INTERNAL_HASH)
-    fc_solve_hash_t hash;
+    hash_table hash;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GOOGLE_DENSE_HASH)
-    fcs_states_google_hash_handle_t hash;
+    fcs_states_google_hash_handle hash;
 #endif
 
 #if defined(INDIRECT_STACK_STATES)
@@ -602,9 +609,9 @@ struct fc_solve_instance_struct
  * used.
  * */
 #if (FCS_STACK_STORAGE == FCS_STACK_STORAGE_INTERNAL_HASH)
-    fc_solve_hash_t stacks_hash;
+    hash_table stacks_hash;
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_LIBAVL2_TREE)
-    fcs_libavl2_stacks_tree_table_t *stacks_tree;
+    fcs_libavl2_stacks_tree_table *stacks_tree;
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_LIBREDBLACK_TREE)
     struct rbtree *stacks_tree;
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_GLIB_TREE)
@@ -612,7 +619,7 @@ struct fc_solve_instance_struct
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_GLIB_HASH)
     GHashTable *stacks_hash;
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_GOOGLE_DENSE_HASH)
-    fcs_columns_google_hash_handle_t stacks_hash;
+    fcs_columns_google_hash_handle stacks_hash;
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_JUDY)
     Pvoid_t stacks_judy_array;
 #else
@@ -620,7 +627,7 @@ struct fc_solve_instance_struct
 #endif
 #endif
 
-    fcs_collectible_state_t *list_of_vacant_states;
+    fcs_collectible_state *list_of_vacant_states;
 /*
  * Storing using Berkeley DB is not operational for some reason so
  * pay no attention to it for the while
@@ -630,21 +637,21 @@ struct fc_solve_instance_struct
 #endif
 
 #ifndef FCS_HARD_CODE_CALC_REAL_DEPTH_AS_FALSE
-    fcs_bool_t FCS_RUNTIME_CALC_REAL_DEPTH;
+    bool FCS_RUNTIME_CALC_REAL_DEPTH;
 #endif
 #ifndef FCS_HARD_CODE_REPARENT_STATES_AS_FALSE
-    fcs_bool_t FCS_RUNTIME_TO_REPARENT_STATES_REAL;
+    bool FCS_RUNTIME_TO_REPARENT_STATES_REAL;
 #endif
 #ifndef FCS_HARD_CODE_SCANS_SYNERGY_AS_TRUE
-    fcs_bool_t FCS_RUNTIME_SCANS_SYNERGY;
+    bool FCS_RUNTIME_SCANS_SYNERGY;
 #endif
 #ifndef FCS_HARD_CODE_REPARENT_STATES_AS_FALSE
-    fcs_bool_t FCS_RUNTIME_TO_REPARENT_STATES_PROTO;
+    bool FCS_RUNTIME_TO_REPARENT_STATES_PROTO;
 #endif
     ;
 #ifdef FCS_WITH_MOVES
-    fcs_bool_t FCS_RUNTIME_OPTIMIZE_SOLUTION_PATH,
-        FCS_RUNTIME_IN_OPTIMIZATION_THREAD, FCS_RUNTIME_OPT_TESTS_ORDER_WAS_SET;
+    bool FCS_RUNTIME_OPTIMIZE_SOLUTION_PATH, FCS_RUNTIME_IN_OPTIMIZATION_THREAD,
+        FCS_RUNTIME_OPT_TESTS_ORDER_WAS_SET;
 #endif
 
 /*
@@ -662,7 +669,7 @@ struct fc_solve_instance_struct
 #ifdef FCS_SINGLE_HARD_THREAD
     struct fc_solve_hard_thread_struct hard_thread;
 #ifdef FCS_WITH_MOVES
-    fcs_bool_t is_optimization_st;
+    bool is_optimization_st;
     struct fc_solve_soft_thread_struct optimization_soft_thread;
 #endif
 #else
@@ -671,7 +678,7 @@ struct fc_solve_instance_struct
     /*
      * An iterator over the hard threads.
      * */
-    fc_solve_hard_thread_t *current_hard_thread;
+    fcs_hard_thread *current_hard_thread;
 
 #ifdef FCS_WITH_MOVES
     /*
@@ -690,7 +697,7 @@ struct fc_solve_instance_struct
      * to this hard thread have already finished. If it becomes
      * num_hard_threads the instance terminates.
      * */
-    int num_hard_threads_finished;
+    uint_fast32_t num_hard_threads_finished;
 
 #ifdef FCS_WITH_MOVES
     // The moves for the optimization scan, as specified by the user.
@@ -698,12 +705,12 @@ struct fc_solve_instance_struct
 #endif
 
 #ifdef FCS_RCS_STATES
-    fcs_lru_cache_t rcs_states_cache;
+    fcs_lru_cache rcs_states_cache;
 
 #if ((FCS_STATE_STORAGE == FCS_STATE_STORAGE_LIBAVL2_TREE) ||                  \
      (FCS_STATE_STORAGE == FCS_STATE_STORAGE_KAZ_TREE))
-    fcs_state_t *tree_new_state_key;
-    fcs_collectible_state_t *tree_new_state;
+    fcs_state *tree_new_state_key;
+    fcs_collectible_state *tree_new_state;
 #endif
 
 #endif
@@ -724,8 +731,8 @@ struct fc_solve_instance_struct
      *
      * This feature is used by the "-s" and "-i" flags of fc-solve-debug.
      * */
-    fcs_instance_debug_iter_output_func_t debug_iter_output_func;
-    fcs_instance_debug_iter_output_context_t debug_iter_output_context;
+    instance_debug_iter_output_func debug_iter_output_func;
+    void *debug_iter_output_context;
 #endif
 
     /*
@@ -734,13 +741,13 @@ struct fc_solve_instance_struct
     int next_soft_thread_id;
 
     /* This is the initial state */
-    fcs_state_keyval_pair_t state_copy;
+    fcs_state_keyval_pair state_copy;
 
 #ifdef FCS_WITH_MOVES
     /* This is the final state that the scan recommends to the
      * interface
      * */
-    fcs_collectible_state_t *final_state;
+    fcs_collectible_state *final_state;
 
     /*
      * A move stack that contains the moves leading to the solution.
@@ -748,13 +755,13 @@ struct fc_solve_instance_struct
      * It is created only after the solution was found by swallowing
      * all the stacks of each depth.
      * */
-    fcs_move_stack_t solution_moves;
+    fcs_move_stack solution_moves;
 #endif
 
     /*
      * The meta allocator - see meta_alloc.h.
      * */
-    fcs_meta_compact_allocator_t *meta_alloc;
+    meta_allocator *meta_alloc;
 
 #if (defined(FCS_WITH_MOVES) && (!defined(FCS_DISABLE_PATSOLVE)))
     /*
@@ -762,7 +769,7 @@ struct fc_solve_instance_struct
      *
      * Needed to trace the patsolve solutions.
      * */
-    fc_solve_soft_thread_t *solving_soft_thread;
+    fcs_soft_thread *solving_soft_thread;
 #endif
 #ifndef FCS_DISABLE_PATSOLVE
     /*
@@ -770,26 +777,17 @@ struct fc_solve_instance_struct
      * sensitive to the ordering of the columns/stacks. This is an ugly hack
      * but hopefully it will work.
      * */
-    fcs_state_keyval_pair_t *initial_non_canonized_state;
+    fcs_state_keyval_pair *initial_non_canonized_state;
 #endif
 
 #ifndef FCS_DISABLE_SIMPLE_SIMON
     /*
      * Whether or not this is a Simple Simon-like game.
      * */
-    fcs_bool_t is_simple_simon;
+    bool is_simple_simon;
 #endif
 };
 
-#ifdef FCS_SINGLE_HARD_THREAD
-#define HT_FIELD(ht, field) (ht)->hard_thread.field
-#define HT_INSTANCE(hard_thread) (hard_thread)
-#define INST_HT0(instance) ((instance)->hard_thread)
-#else
-#define HT_FIELD(hard_thread, field) (hard_thread)->field
-#define HT_INSTANCE(hard_thread) ((hard_thread)->instance)
-#define INST_HT0(instance) ((instance)->hard_threads[0])
-#endif
 #define fcs_st_instance(soft_thread) HT_INSTANCE((soft_thread)->hard_thread)
 
 #define DFS_VAR(soft_thread, var) (soft_thread)->method_specific.soft_dfs.var
@@ -815,7 +813,7 @@ struct fc_solve_instance_struct
 #endif
 
 extern fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
-    fc_solve_soft_thread_t *const soft_thread);
+    fcs_soft_thread *const soft_thread);
 
 static inline void *memdup(const void *const src, const size_t my_size)
 {
@@ -834,12 +832,12 @@ static inline int update_col_cards_under_sequences(
 #ifndef FCS_FREECELL_ONLY
     const int sequences_are_built_by,
 #endif
-    const fcs_const_cards_column_t col,
+    const fcs_const_cards_column col,
     int d /* One less than cards_num of col. */
 )
 {
-    fcs_card_t this_card = fcs_col_get_card(col, d);
-    fcs_card_t prev_card;
+    fcs_card this_card = fcs_col_get_card(col, d);
+    fcs_card prev_card;
     for (; (d > 0) && ({
              prev_card = fcs_col_get_card(col, d - 1);
              fcs_is_parent_card(this_card, prev_card);
@@ -850,28 +848,28 @@ static inline int update_col_cards_under_sequences(
     return d;
 }
 
-extern fcs_collectible_state_t *fc_solve_sfs_raymond_prune(
-    fc_solve_soft_thread_t *, fcs_kv_state_t);
+extern fcs_collectible_state *fc_solve_sfs_raymond_prune(
+    fcs_soft_thread *, fcs_kv_state);
 
 #ifdef FCS_RCS_STATES
-fcs_state_t *fc_solve_lookup_state_key_from_val(fc_solve_instance_t *instance,
-    const fcs_collectible_state_t *orig_ptr_state_val);
+fcs_state *fc_solve_lookup_state_key_from_val(
+    fcs_instance *instance, const fcs_collectible_state *orig_ptr_state_val);
 
 extern int fc_solve_compare_lru_cache_keys(const void *, const void *, void *);
 
 #endif
 
 extern void fc_solve_soft_thread_init_befs_or_bfs(
-    fc_solve_soft_thread_t *const soft_thread);
+    fcs_soft_thread *const soft_thread);
 
 extern void fc_solve_instance__init_hard_thread(
 #ifndef FCS_SINGLE_HARD_THREAD
-    fc_solve_instance_t *const instance,
+    fcs_instance *const instance,
 #endif
-    fc_solve_hard_thread_t *const hard_thread);
+    fcs_hard_thread *const hard_thread);
 
 extern void fc_solve_free_soft_thread_by_depth_move_array(
-    fc_solve_soft_thread_t *const soft_thread);
+    fcs_soft_thread *const soft_thread);
 
 static inline fcs_moves_order moves_order_dup(fcs_moves_order *const orig)
 {
@@ -891,13 +889,13 @@ static inline fcs_moves_order moves_order_dup(fcs_moves_order *const orig)
     return ret;
 }
 
-extern fc_solve_soft_thread_t *fc_solve_new_soft_thread(
-    fc_solve_hard_thread_t *const hard_thread);
+extern fcs_soft_thread *fc_solve_new_soft_thread(
+    fcs_hard_thread *const hard_thread);
 
 /* This is the commmon code from fc_solve_instance__init_hard_thread() and
  * recycle_hard_thread() */
 static inline void fc_solve_reset_hard_thread(
-    fc_solve_hard_thread_t *const hard_thread)
+    fcs_hard_thread *const hard_thread)
 {
 #ifndef FCS_SINGLE_HARD_THREAD
     HT_FIELD(hard_thread, ht__num_checked_states) = 0;
@@ -907,22 +905,22 @@ static inline void fc_solve_reset_hard_thread(
 }
 
 static inline void fc_solve_reset_soft_thread(
-    fc_solve_soft_thread_t *const soft_thread)
+    fcs_soft_thread *const soft_thread)
 {
     STRUCT_CLEAR_FLAG(soft_thread, FCS_SOFT_THREAD_IS_FINISHED);
     STRUCT_CLEAR_FLAG(soft_thread, FCS_SOFT_THREAD_INITIALIZED);
 }
 
-typedef enum {
+typedef enum
+{
     FOREACH_SOFT_THREAD_CLEAN_SOFT_DFS,
     FOREACH_SOFT_THREAD_FREE_INSTANCE,
     FOREACH_SOFT_THREAD_ACCUM_TESTS_ORDER,
     FOREACH_SOFT_THREAD_DETERMINE_SCAN_COMPLETENESS
-} fcs_foreach_st_callback_choice_t;
+} foreach_st_callback_choice;
 
-extern void fc_solve_foreach_soft_thread(fc_solve_instance_t *const instance,
-    const fcs_foreach_st_callback_choice_t callback_choice,
-    void *const context);
+extern void fc_solve_foreach_soft_thread(fcs_instance *const instance,
+    const foreach_st_callback_choice callback_choice, void *const context);
 
 /*
     This function is the last function that should be called in the
@@ -943,37 +941,27 @@ static inline void moves_order__free(fcs_moves_order *moves_order)
     moves_order->num = 0;
 }
 
-    /***********************************************************/
+/***********************************************************/
+#define MOVE_FUNC_ARGS                                                         \
+    fcs_soft_thread *const soft_thread GCC_UNUSED,                             \
+        fcs_kv_state raw_state_raw GCC_UNUSED,                                 \
+        fcs_derived_states_list *const derived_states_list GCC_UNUSED
 
-#define DECLARE_MOVE_FUNCTION(name)                                            \
-    extern void name(fc_solve_soft_thread_t *const soft_thread,                \
-        fcs_kv_state_t raw_state_raw,                                          \
-        fcs_derived_states_list_t *const derived_states_list)
-
-#ifdef FCS_SINGLE_HARD_THREAD
-extern void fc_solve_init_soft_thread(fc_solve_hard_thread_t *const hard_thread,
-    fc_solve_soft_thread_t *const soft_thread);
-#endif
+#define DECLARE_MOVE_FUNCTION(name) extern void name(MOVE_FUNC_ARGS)
+#define DECLARE_PURE_MOVE_FUNCTION(name) extern void name(MOVE_FUNC_ARGS)
 
 #ifndef FCS_HARD_CODE_CALC_REAL_DEPTH_AS_FALSE
-static inline fcs_bool_t fcs_get_calc_real_depth(
-    const fc_solve_instance_t *const instance)
+static inline bool fcs_get_calc_real_depth(const fcs_instance *const instance)
 {
     return STRUCT_QUERY_FLAG(instance, FCS_RUNTIME_CALC_REAL_DEPTH);
 }
 #endif
 
 #ifdef FCS_WITH_MOVES
-extern void fc_solve_trace_solution(fc_solve_instance_t *const instance);
+extern void fc_solve_trace_solution(fcs_instance *const instance);
 #endif
-extern void fc_solve_finish_instance(fc_solve_instance_t *const instance);
+extern void fc_solve_finish_instance(fcs_instance *const instance);
 
 #ifdef __cplusplus
 }
 #endif
-
-#ifdef FCS_SINGLE_HARD_THREAD
-#define NUM_CHECKED_STATES (HT_INSTANCE(hard_thread)->i__num_checked_states)
-#else
-#define NUM_CHECKED_STATES HT_FIELD(hard_thread, ht__num_checked_states)
-#endif
