@@ -277,21 +277,21 @@ static int verify_dict_has_node(dnode_t *nil, dnode_t *root, dnode_t *node)
 }
 #endif
 
-    /*
-     * Dynamically allocate and initialize a dictionary object.
-     */
+/*
+ * Dynamically allocate and initialize a dictionary object.
+ */
 
 #ifdef NO_FC_SOLVE
 dict_t *dict_create(dictcount_t maxcount, dict_comp_t comp, void *context)
 #else
-dict_t *fc_solve_kaz_tree_create(dict_comp_t comp, void *context,
-    fcs_meta_compact_allocator_t *meta_allocator)
+dict_t *fc_solve_kaz_tree_create(
+    dict_comp_t comp, void *context, meta_allocator *meta_alloc)
 #endif
 {
     dict_t *dict = (dict_t *)SMALLOC1(dict);
 
     if (dict)
-        dict_init(dict, comp, meta_allocator);
+        dict_init(dict, comp, meta_alloc);
 
     dict->context = context;
 
@@ -405,15 +405,14 @@ void dict_free(dict_t *dict)
 }
 #endif
 
-    /*
-     * Initialize a user-supplied dictionary object.
-     */
+/*
+ * Initialize a user-supplied dictionary object.
+ */
 
 #ifdef NO_FC_SOLVE
 dict_t *dict_init(dict_t *dict, dictcount_t maxcount, dict_comp_t comp)
 #else
-dict_t *dict_init(dict_t *dict, dict_comp_t comp,
-    fcs_meta_compact_allocator_t *meta_allocator)
+dict_t *dict_init(dict_t *dict, dict_comp_t comp, meta_allocator *meta_alloc)
 #endif
 {
     dict->compare = comp;
@@ -422,7 +421,7 @@ dict_t *dict_init(dict_t *dict, dict_comp_t comp,
     dict->allocnode = dnode_alloc;
     dict->freenode = dnode_free;
 #else
-    fc_solve_compact_allocator_init(&(dict->dict_allocator), meta_allocator);
+    fc_solve_compact_allocator_init(&(dict->dict_allocator), meta_alloc);
     dict->dict_recycle_bin = NULL;
 #endif
 
@@ -1146,10 +1145,10 @@ static inline dnode_t *dnode_init(dnode_t *dnode)
     return dnode;
 }
 
-    /*
-     * Allocate a node using the dictionary's allocator routine, give it
-     * the data item.
-     */
+/*
+ * Allocate a node using the dictionary's allocator routine, give it
+ * the data item.
+ */
 
 #ifdef NO_FC_SOLVE
 dict_ret_key_t fc_solve_kaz_tree_alloc_insert(
@@ -1161,7 +1160,7 @@ dict_ret_key_t fc_solve_kaz_tree_alloc_insert(dict_t *dict, dict_key_t key)
     dnode_t *from_bin;
     dnode_t *node;
     dict_ret_key_t ret;
-    fcs_compact_allocator_t *const allocator = &(dict->dict_allocator);
+    compact_allocator *const allocator = &(dict->dict_allocator);
     if ((from_bin = dict->dict_recycle_bin) != NULL)
     {
         node = dict->dict_recycle_bin;
@@ -1204,7 +1203,7 @@ void fc_solve_kaz_tree_delete_free(dict_t *dict, dnode_t *node)
 #endif
 }
 
-dnode_t *fc_solve_kaz_tree_first(dict_t *dict)
+__attribute__((pure)) dnode_t *fc_solve_kaz_tree_first(dict_t *dict)
 {
     dnode_t *nil = dict_nil(dict), *root = dict_root(dict), *left;
 
@@ -1245,7 +1244,8 @@ dnode_t *dict_last(dict_t *dict)
  */
 #endif
 
-dnode_t *fc_solve_kaz_tree_next(dict_t *dict, dnode_t *curr)
+__attribute__((pure)) dnode_t *fc_solve_kaz_tree_next(
+    dict_t *dict, dnode_t *curr)
 {
     dnode_t *nil = dict_nil(dict), *parent, *left;
 
