@@ -11,10 +11,5 @@
 // and unlikely macros. See: https://lwn.net/Articles/255364/ .
 #pragma once
 
-#ifdef __GNUC__
 #define unlikely(expr) __builtin_expect(!!(expr), 0)
 #define likely(expr) __builtin_expect(!!(expr), 1)
-#else
-#define unlikely(expr) expr
-#define likely(expr) expr
-#endif
