@@ -24,7 +24,7 @@ typedef struct
 {
     struct timeval tv;
     struct timezone tz;
-} fcs_portable_time_t;
+} fcs_portable_time;
 
 #define FCS_GET_TIME(pt) gettimeofday(&((pt).tv), &((pt).tz))
 #define FCS_TIME_GET_SEC(pt) ((long long)((pt).tv.tv_sec))
@@ -39,7 +39,7 @@ typedef struct
 typedef struct
 {
     struct _timeb tb;
-} fcs_portable_time_t;
+} fcs_portable_time;
 
 #define FCS_GET_TIME(pt) _ftime(&((pt).tb))
 #define FCS_TIME_GET_SEC(pt) ((long long)((pt).tb.time))
@@ -49,9 +49,9 @@ typedef struct
 #define FCS_LL9_FMT "%09I64d"
 #endif
 
-static inline fcs_portable_time_t fcs_get_time(void)
+static inline fcs_portable_time fcs_get_time(void)
 {
-    fcs_portable_time_t ret;
+    fcs_portable_time ret;
     FCS_GET_TIME(ret);
     return ret;
 }
@@ -78,6 +78,13 @@ static inline void fc_solve_print_started_at(void)
         FCS_TIME_GET_USEC(mytime));
 }
 
+static inline void fc_solve_print_reached_no_iters(const long long board_num)
+{
+    const_AUTO(mytime, fcs_get_time());
+    printf("Reached " FCS_B_AT_FMT "\n", board_num, FCS_TIME_GET_SEC(mytime),
+        FCS_TIME_GET_USEC(mytime));
+}
+
 static inline void fc_solve_print_reached(
     const long long board_num, const long long total_num_iters)
 {
