@@ -18,7 +18,7 @@ extern "C" {
 #endif
 
 #include "rinutils.h"
-#include "fcs_cl.h"
+#include "freecell-solver/fcs_cl.h"
 
 typedef struct
 {
@@ -27,20 +27,20 @@ typedef struct
     char *buffer_end;
     char *ptr;
     const char *filename;
-} binary_output_t;
+} fcs_binary_output;
 
-static const binary_output_t INIT_BINARY_OUTPUT = {.filename = NULL};
+static const fcs_binary_output INIT_BINARY_OUTPUT = {.filename = NULL};
 
 #define BINARY_OUTPUT_BUF_SIZE (sizeof(int) * 16)
 #define SIZE_INT 4
 
-static inline void write_me(binary_output_t *const bin)
+static inline void write_me(fcs_binary_output *const bin)
 {
     fwrite(bin->buffer, 1, (size_t)(bin->ptr - bin->buffer), bin->fh);
     fflush(bin->fh);
 }
 
-static void print_int(binary_output_t *const bin, int val)
+static void print_int(fcs_binary_output *const bin, int val)
 {
     if (!bin->fh)
     {
@@ -61,7 +61,7 @@ static void print_int(binary_output_t *const bin, int val)
     }
 }
 
-static inline void bin_close(binary_output_t *const bin)
+static inline void bin_close(fcs_binary_output *const bin)
 {
     if (bin->filename)
     {
@@ -72,7 +72,7 @@ static inline void bin_close(binary_output_t *const bin)
     }
 }
 
-static inline fcs_bool_t read_int(FILE *const f, long long *const dest)
+static inline bool read_int(FILE *const f, long long *const dest)
 {
     unsigned char buffer[SIZE_INT];
     if (fread(buffer, 1, SIZE_INT, f) != SIZE_INT)
@@ -94,7 +94,7 @@ static void read_int_wrapper(FILE *const in, long long *const var)
     }
 }
 
-static inline void bin_init(binary_output_t *const bin,
+static inline void bin_init(fcs_binary_output *const bin,
     long long *const start_board_ptr, long long *const end_board_ptr,
     fcs_int_limit_t *const total_iterations_limit_per_board_ptr)
 {
