@@ -7,11 +7,9 @@
  *
  * Copyright (c) 2000 Shlomi Fish
  */
-/*
- * range_solvers_gen_ms_boards.h - a header file that defines some
- * static (and preferably inline) routines for generating the Microsoft
- * boards.
- */
+// range_solvers_gen_ms_boards.h - a header file that defines some
+// static (and preferably inline) routines for generating the Microsoft
+// boards.
 #pragma once
 
 #ifdef __cplusplus
@@ -20,13 +18,11 @@ extern "C" {
 
 #include "gen_ms_boards__rand.h"
 
-typedef int CARD;
+typedef size_t CARD;
 
 #define SUIT(card) ((card) & (4 - 1))
 #define VALUE(card) ((card) >> 2)
 
-#define MAXCOL 8
-
 static const char *card_to_string_values = "A23456789TJQK";
 static const char *card_to_string_suits = "CDHS";
 
@@ -36,6 +32,7 @@ static inline void card_to_string(char *const s, const CARD card)
     s[1] = card_to_string_suits[SUIT(card)];
 }
 
+#include "board_gen_lookup1.h"
 #ifdef FCS_GEN_BOARDS_WITH_EXTERNAL_API
 /* This is to settle gcc's -Wmissing-prototypes which complains about
  * missing prototypes for "extern" subroutines.
@@ -69,20 +66,17 @@ static inline void get_board_l(const long long deal_idx, char *const ret)
 
     /* shuffle cards */
 
-    for (int i = 0; i < 52; i++) /* put unique card in each deck loc. */
+    for (size_t i = 0; i < 52; ++i) /* put unique card in each deck loc. */
     {
         deck[i] = i;
     }
 
-    microsoft_rand_uint_t num_cards_left = 52;
-    for (int i = 0; i < 52; i++)
+    microsoft_rand_uint num_cards_left = 52;
+    for (size_t i = 0; i < 52; ++i)
     {
-        const microsoft_rand_uint_t j =
+        const microsoft_rand_uint j =
             microsoft_rand__game_num_rand(&seedx, deal_idx) % num_cards_left;
-        const int col = (i & (8 - 1));
-        card_to_string(
-            &ret[3 * (col * 7 - ((col > 4) ? (col - 4) : 0) + (i >> 3))],
-            deck[j]);
+        card_to_string(&ret[offset_by_i[i]], deck[j]);
         deck[j] = deck[--num_cards_left];
     }
 }
@@ -94,7 +88,7 @@ static inline void get_board(long deal_idx, char *ret)
 }
 #endif
 
-typedef char fcs_state_string_t[52 * 3 + 8 + 1];
+typedef char fcs_state_string[52 * 3 + 8 + 1];
 
 #ifdef __cplusplus
 }
