@@ -14,11 +14,11 @@
 typedef struct
 {
     char s[USER_STATE_SIZE];
-} fcs_user_state_str_t;
+} fcs_user_state_str;
 
-static inline fcs_user_state_str_t read_state(FILE *f)
+static inline fcs_user_state_str read_state(FILE *f)
 {
-    fcs_user_state_str_t user_state;
+    fcs_user_state_str user_state;
     memset(user_state.s, '\0', sizeof(user_state));
     fread(user_state.s, sizeof(user_state.s[0]), USER_STATE_SIZE - 1, f);
     fclose(f);
