@@ -19,9 +19,9 @@
 #include "alloc_wrap.h"
 #include "bool.h"
 #include "count.h"
-#include "fcs_dllexport.h"
+#include "freecell-solver/fcs_dllexport.h"
 #include "fcs_err.h"
-#include "fcs_limit.h"
+#include "freecell-solver/fcs_limit.h"
 #include "likely.h"
 #include "min_and_max.h"
 #include "portable_time.h"
