@@ -17,10 +17,11 @@ extern "C" {
 #endif
 
 #include "rinutils.h"
-#include "fcs_user.h"
+#include "freecell-solver/fcs_user.h"
 
 static inline void fc_solve_set_weights(freecell_solver_str_t start_num,
-    const freecell_solver_str_t string_end, double *const befs_weights)
+    const freecell_solver_str_t string_end,
+    fc_solve_weighting_float *const befs_weights)
 {
     for (int i = 0; i < FCS_NUM_BEFS_WEIGHTS; ++i)
     {
