@@ -7,15 +7,12 @@
  *
  * Copyright (c) 2000 Shlomi Fish
  */
-/*
- * state.c - state functions module for Freecell Solver
- */
-
+// state.c - state functions module for Freecell Solver
 #include "state.h"
-#include "fcs_enums.h"
+#include "freecell-solver/fcs_enums.h"
 
 #ifdef COMPACT_STATES
-#define GET_CARD(s) (((const fcs_card_t *const)(s))[1])
+#define GET_CARD(s) (((const fcs_card *const)(s))[1])
 static inline int fcs_stack_compare(const void *s1, const void *s2)
 {
     return fc_solve_card_compare(GET_CARD(s1), GET_CARD(s2));
@@ -32,16 +29,18 @@ static inline int fcs_stack_compare(const void *s1, const void *s2)
 
 #elif defined(INDIRECT_STACK_STATES)
 
-#define DECLARE_TEMP_STACK() fcs_card_t *temp_stack
+#define DECLARE_TEMP_STACK() fcs_card *temp_stack
 #define STACK_COMPARE(a, b) (fc_solve_stack_compare_for_comparison(a, b))
 #define GET_STACK(c) (state_key->columns[c])
 #define COPY_STACK(d, s) (d = s)
 
 #endif
+#if MAX_NUM_FREECELLS > 0
 #define GET_FREECELL(c) (fcs_freecell_card(*state_key, (c)))
+#endif
 
 void fc_solve_canonize_state(
-    fcs_state_t *const ptr_state_key FREECELLS_AND_STACKS_ARGS())
+    fcs_state *const ptr_state_key FREECELLS_AND_STACKS_ARGS())
 {
 #define state_key (ptr_state_key)
     /* Insertion-sort the columns */
@@ -62,8 +61,8 @@ void fc_solve_canonize_state(
         }
     }
 
-    /* Insertion-sort the freecells */
-
+#if MAX_NUM_FREECELLS > 0
+    // Insertion-sort the freecells
     for (size_t b = 1; b < FREECELLS_NUM__VAL; b++)
     {
         size_t c = b;
@@ -71,22 +70,23 @@ void fc_solve_canonize_state(
         while ((c > 0) && ((fc_solve_card_compare(
                                GET_FREECELL(c), GET_FREECELL(c - 1))) < 0))
         {
-            const fcs_card_t temp_freecell = GET_FREECELL(c);
+            const fcs_card temp_freecell = GET_FREECELL(c);
             GET_FREECELL(c) = GET_FREECELL(c - 1);
             GET_FREECELL(c - 1) = temp_freecell;
 
             --c;
         }
     }
+#endif
 }
 #undef state_key
 
 #ifdef FCS_WITH_MOVES
-void fc_solve_canonize_state_with_locs(fcs_state_t *const ptr_state_key,
+void fc_solve_canonize_state_with_locs(fcs_state *const ptr_state_key,
 #define state_key (ptr_state_key)
-    fcs_state_locs_struct_t *const locs FREECELLS_AND_STACKS_ARGS())
+    fcs_state_locs_struct *const locs FREECELLS_AND_STACKS_ARGS())
 {
-    /* Insertion-sort the columns */
+    // Insertion-sort the columns
     for (size_t b = 1; b < STACKS_NUM__VAL; b++)
     {
         size_t c = b;
@@ -107,8 +107,8 @@ void fc_solve_canonize_state_with_locs(fcs_state_t *const ptr_state_key,
         }
     }
 
-    /* Insertion-sort the freecells */
-
+#if MAX_NUM_FREECELLS > 0
+    // Insertion-sort the freecells
     for (size_t b = 1; b < FREECELLS_NUM__VAL; b++)
     {
         size_t c = b;
@@ -116,7 +116,7 @@ void fc_solve_canonize_state_with_locs(fcs_state_t *const ptr_state_key,
         while ((c > 0) && ((fc_solve_card_compare(
                                GET_FREECELL(c), GET_FREECELL(c - 1))) < 0))
         {
-            const fcs_card_t temp_freecell = GET_FREECELL(c);
+            const fcs_card temp_freecell = GET_FREECELL(c);
             GET_FREECELL(c) = GET_FREECELL(c - 1);
             GET_FREECELL(c - 1) = temp_freecell;
 
@@ -127,6 +127,7 @@ void fc_solve_canonize_state_with_locs(fcs_state_t *const ptr_state_key,
             --c;
         }
     }
+#endif
 }
 #undef state_key
 #endif
@@ -134,21 +135,22 @@ void fc_solve_canonize_state_with_locs(fcs_state_t *const ptr_state_key,
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
 int fc_solve_state_compare_equal(const void *const s1, const void *const s2)
 {
-    return (!memcmp(s1, s2, sizeof(fcs_state_t)));
+    return (!memcmp(s1, s2, sizeof(fcs_state)));
 }
 #endif
 
 int __attribute__((pure))
 fc_solve_state_compare_with_context(const void *const s1, const void *const s2,
-    fcs_compare_context_t context GCC_UNUSED)
+    fcs_compare_context context GCC_UNUSED)
 {
-    return memcmp(s1, s2, sizeof(fcs_state_t));
+    return memcmp(s1, s2, sizeof(fcs_state));
 }
 
 #ifdef FCS_WITH_MOVES
 #include "rank2str.h"
-static inline void render_freecell_card(const fcs_card_t card,
-    char *const freecell PASS_T(const fcs_bool_t display_10_as_t))
+#if MAX_NUM_FREECELLS > 0
+static inline void render_freecell_card(const fcs_card card,
+    char *const freecell PASS_T(const bool display_10_as_t))
 {
     if (fcs_card_is_empty(card))
     {
@@ -159,13 +161,12 @@ static inline void render_freecell_card(const fcs_card_t card,
         fc_solve_card_stringify(card, freecell PASS_T(display_10_as_t));
     }
 }
+#endif
 
-void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
-    const fcs_state_locs_struct_t *const state_locs
-        FREECELLS_STACKS_DECKS__ARGS()
-            FC_SOLVE__PASS_PARSABLE(const fcs_bool_t parseable_output),
-    const fcs_bool_t canonized_order_output PASS_T(
-        const fcs_bool_t display_10_as_t))
+void fc_solve_state_as_string(char *output_s, const fcs_state *const state,
+    const fcs_state_locs_struct *const state_locs FREECELLS_STACKS_DECKS__ARGS()
+        FC_SOLVE__PASS_PARSABLE(const bool parseable_output),
+    const bool canonized_order_output PASS_T(const bool display_10_as_t))
 {
     typedef char one_card_buffer[4];
     char founds[MAX_NUM_DECKS * 4][10];
@@ -175,7 +176,9 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
 #define append_char(c) *(output_s++) = (c)
 
     size_t stack_locs[MAX_NUM_STACKS];
+#if MAX_NUM_FREECELLS > 0
     size_t freecell_locs[MAX_NUM_FREECELLS];
+#endif
 
     if (canonized_order_output)
     {
@@ -183,10 +186,12 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
         {
             stack_locs[i] = i;
         }
+#if MAX_NUM_FREECELLS > 0
         for (size_t i = 0; i < FREECELLS_NUM__VAL; i++)
         {
             freecell_locs[i] = i;
         }
+#endif
     }
     else
     {
@@ -194,10 +199,12 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
         {
             stack_locs[(int)(state_locs->stack_locs[i])] = i;
         }
+#if MAX_NUM_FREECELLS > 0
         for (size_t i = 0; i < FREECELLS_NUM__VAL; i++)
         {
             freecell_locs[(int)(state_locs->fc_locs[i])] = i;
         }
+#endif
     }
 
     for (size_t i = 0; i < (DECKS_NUM__VAL << 2); i++)
@@ -211,17 +218,18 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
 #ifndef FC_SOLVE_IMPLICIT_PARSABLE_OUTPUT
     if (!parseable_output)
     {
-        int i;
-        for (i = 0; i < ((FREECELLS_NUM__VAL / 4) +
-                            ((FREECELLS_NUM__VAL % 4 == (0)) ? 0 : 1));
-             i++)
+        size_t i = 0;
+#if MAX_NUM_FREECELLS > 0
+        for (; i < ((FREECELLS_NUM__VAL / 4) +
+                       ((FREECELLS_NUM__VAL % 4 == (0)) ? 0 : 1));
+             ++i)
         {
             char dashes_s[128];
-            char *dashes_ptr = dashes_s;
             char freecells_s[128];
+            char *dashes_ptr = dashes_s;
             char *freecells_s_end = freecells_s;
             const_AUTO(lim, min(FREECELLS_NUM__VAL - i * 4, 4));
-            for (int b = 0; b < lim; b++)
+            for (size_t b = 0; b < lim; b++)
             {
                 one_card_buffer freecell;
                 render_freecell_card(
@@ -244,6 +252,7 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
             }
             fc_solve_append_string_sprintf("%s\n", dashes_s);
         }
+#endif
         for (; i < DECKS_NUM__VAL; i++)
         {
             fc_solve_append_string_sprintf(
@@ -253,7 +262,7 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
         append_char('\n');
         append_char('\n');
 
-        for (int s = 0; s < STACKS_NUM__VAL; s++)
+        for (size_t s = 0; s < STACKS_NUM__VAL; s++)
         {
             fc_solve_append_string_sprintf("%s", " -- ");
         }
@@ -271,10 +280,10 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
 
         for (size_t card_idx = 0; card_idx < max_num_cards; ++card_idx)
         {
-            for (int s = 0; s < STACKS_NUM__VAL; s++)
+            for (size_t s = 0; s < STACKS_NUM__VAL; s++)
             {
                 const_AUTO(col, fcs_state_get_col(*state, stack_locs[s]));
-                const int col_len = fcs_col_len(col);
+                const size_t col_len = fcs_col_len(col);
                 if (card_idx >= col_len)
                 {
                     fc_solve_append_string_sprintf("%s", "    ");
@@ -305,6 +314,7 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
 
         fc_solve_append_string_sprintf("%s", "\nFreecells:");
 
+#if MAX_NUM_FREECELLS > 0
 #ifdef FC_SOLVE__REMOVE_TRAILING_WHITESPACE_IN_OUTPUT
         int max_freecell_idx = -1;
         for (int i = FREECELLS_NUM__VAL - 1; i >= 0; i--)
@@ -334,6 +344,7 @@ void fc_solve_state_as_string(char *output_s, const fcs_state_t *const state,
                 append_char(' ');
             }
         }
+#endif
         append_char('\n');
 
         for (size_t s = 0; s < STACKS_NUM__VAL; ++s)
