@@ -11,7 +11,7 @@ use FC_Solve::InlineWrap (
 
 SV * _internal_parse_args(char * input) {
     AV *const results = (AV *)sv_2mortal((SV *)newAV());
-    args_man_t args = fc_solve_args_man_chop(input);
+    fcs_args_man args = fc_solve_args_man_chop(input);
 
     for ( int i=0 ; i < args.argc ; i++)
     {
